# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class OSSCreateBucketOperator(BaseOperator):
    region: "str"
    bucket_name: "str | None"
    oss_conn_id: "str"


class OSSDeleteBucketOperator(BaseOperator):
    region: "str"
    bucket_name: "str | None"
    oss_conn_id: "str"


class OSSUploadObjectOperator(BaseOperator):
    key: "str"
    file: "str"
    region: "str"
    bucket_name: "str | None"
    oss_conn_id: "str"


class OSSDownloadObjectOperator(BaseOperator):
    key: "str"
    file: "str"
    region: "str"
    bucket_name: "str | None"
    oss_conn_id: "str"


class OSSDeleteBatchObjectOperator(BaseOperator):
    keys: "list"
    region: "str"
    bucket_name: "str | None"
    oss_conn_id: "str"


class OSSDeleteObjectOperator(BaseOperator):
    key: "str"
    region: "str"
    bucket_name: "str | None"
    oss_conn_id: "str"
