# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class GoogleCampaignManagerReportSensor(BaseSensorOperator):
    profile_id: "str"
    report_id: "str"
    file_id: "str"
    api_version: "str"
    gcp_conn_id: "str"
    delegate_to: "str | None"
    mode: "str"
    poke_interval: "int"
    impersonation_chain: "str | Sequence[str] | None"
