# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class LookerCheckPdtBuildSensor(BaseSensorOperator):
    materialization_id: "str"
    looker_conn_id: "str"
    cancel_on_kill: "bool"
