# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.operators.base_aws import (
    AwsBaseOperator,
)


class RedshiftDataOperator(AwsBaseOperator):
    database: "str"
    sql: "str | list"
    cluster_identifier: "str | None"
    db_user: "str | None"
    parameters: "list | None"
    secret_arn: "str | None"
    statement_name: "str | None"
    with_event: "bool"
    wait_for_completion: "bool"
    poll_interval: "int"
    return_sql_result: "bool"
    workgroup_name: "str | None"
    deferrable: "bool"
