# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class HttpSensor(BaseSensorOperator):
    endpoint: "str"
    http_conn_id: "str"
    method: "str"
    request_params: "dict[str, Any] | None"
    headers: "dict[str, Any] | None"
    response_error_codes_allowlist: "list[str] | None"
    response_check: "Callable[..., bool] | None"
    extra_options: "dict[str, Any] | None"
    tcp_keep_alive: "bool"
    tcp_keep_alive_idle: "int"
    tcp_keep_alive_count: "int"
    tcp_keep_alive_interval: "int"
    deferrable: "bool"
