# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class BaseSqlToSlackOperator(BaseOperator):
    sql: "str"
    sql_conn_id: "str"
    sql_hook_params: "dict | None"
    parameters: "list | tuple | Mapping[str, Any] | None"
    slack_proxy: "str | None"
    slack_timeout: "int | None"
    slack_retry_handlers: "list[RetryHandler] | None"
