# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.sensors.base_aws import AwsBaseSensor
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class GlueJobSensor(BaseSensorOperator):
    job_name: "str"
    run_id: "str"
    verbose: "bool"
    aws_conn_id: "str | None"


class GlueDataQualityRuleSetEvaluationRunSensor(AwsBaseSensor):
    evaluation_run_id: "str"
    show_results: "bool"
    verify_result_status: "bool"
    deferrable: "bool"
    poke_interval: "int"
    max_retries: "int"
    aws_conn_id: "str | None"


class GlueDataQualityRuleRecommendationRunSensor(AwsBaseSensor):
    recommendation_run_id: "str"
    show_results: "bool"
    deferrable: "bool"
    poke_interval: "int"
    max_retries: "int"
    aws_conn_id: "str | None"
