# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.transfers.sql_to_gcs import (
    BaseSQLToGCSOperator,
)


class MSSQLToGCSOperator(BaseSQLToGCSOperator):
    bit_fields: "Sequence[str] | None"
    mssql_conn_id: "_empty"
