# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class LevelDBOperator(BaseOperator):
    command: "str"
    key: "bytes"
    value: "bytes | None"
    keys: "list[bytes] | None"
    values: "list[bytes] | None"
    leveldb_conn_id: "str"
    name: "str"
    create_if_missing: "bool"
    create_db_extra_options: "dict[str, Any] | None"
