# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class AzureBlobStorageToS3Operator(BaseOperator):
    wasb_conn_id: "str"
    container_name: "str"
    prefix: "str | None"
    delimiter: "str"
    aws_conn_id: "str | None"
    dest_s3_key: "str"
    dest_verify: "str | bool | None"
    dest_s3_extra_args: "dict | None"
    replace: "bool"
    s3_acl_policy: "str | None"
    wasb_extra_args: "dict | None"
    s3_extra_args: "dict | None"
