# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class OracleToOracleOperator(BaseOperator):
    oracle_destination_conn_id: "str"
    destination_table: "str"
    oracle_source_conn_id: "str"
    source_sql: "str"
    source_sql_params: "dict | None"
    rows_chunk: "int"
