# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class BigQueryCreateDataTransferOperator(GoogleCloudBaseOperator):
    transfer_config: "dict"
    project_id: "str"
    location: "str | None"
    authorization_code: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "_empty"
    impersonation_chain: "str | Sequence[str] | None"


class BigQueryDeleteDataTransferConfigOperator(GoogleCloudBaseOperator):
    transfer_config_id: "str"
    project_id: "str"
    location: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "_empty"
    impersonation_chain: "str | Sequence[str] | None"


class BigQueryDataTransferServiceStartTransferRunsOperator(GoogleCloudBaseOperator):
    transfer_config_id: "str"
    project_id: "str"
    location: "str | None"
    requested_time_range: "dict | None"
    requested_run_time: "dict | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "_empty"
    impersonation_chain: "str | Sequence[str] | None"
    deferrable: "bool"
