# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class BatchSensor(BaseSensorOperator):
    job_id: "str"
    aws_conn_id: "str | None"
    region_name: "str | None"
    deferrable: "bool"
    poke_interval: "float"
    max_retries: "int"


class BatchComputeEnvironmentSensor(BaseSensorOperator):
    compute_environment: "str"
    aws_conn_id: "str | None"
    region_name: "str | None"


class BatchJobQueueSensor(BaseSensorOperator):
    job_queue: "str"
    treat_non_existing_as_deleted: "bool"
    aws_conn_id: "str | None"
    region_name: "str | None"
