# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.operators.base_aws import (
    AwsBaseOperator,
)


class ComprehendBaseOperator(AwsBaseOperator):
    input_data_config: "dict"
    output_data_config: "dict"
    data_access_role_arn: "str"
    language_code: "str"


class ComprehendStartPiiEntitiesDetectionJobOperator(ComprehendBaseOperator):
    input_data_config: "dict"
    output_data_config: "dict"
    mode: "str"
    data_access_role_arn: "str"
    language_code: "str"
    start_pii_entities_kwargs: "dict[str, Any] | None"
    wait_for_completion: "bool"
    waiter_delay: "int"
    waiter_max_attempts: "int"
    deferrable: "bool"


class ComprehendCreateDocumentClassifierOperator(AwsBaseOperator):
    document_classifier_name: "str"
    input_data_config: "dict[str, Any]"
    mode: "str"
    data_access_role_arn: "str"
    language_code: "str"
    fail_on_warnings: "bool"
    output_data_config: "dict[str, Any] | None"
    document_classifier_kwargs: "dict[str, Any] | None"
    wait_for_completion: "bool"
    waiter_delay: "int"
    waiter_max_attempts: "int"
    deferrable: "bool"
    aws_conn_id: "str | None"
