# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class DataflowCreateJavaJobOperator(GoogleCloudBaseOperator):
    pass


class DataflowTemplatedJobStartOperator(GoogleCloudBaseOperator):
    template: "str"
    project_id: "str"
    job_name: "str"
    options: "dict[str, Any] | None"
    dataflow_default_options: "dict[str, Any] | None"
    parameters: "dict[str, str] | None"
    location: "str | None"
    gcp_conn_id: "str"
    poll_sleep: "int"
    impersonation_chain: "str | Sequence[str] | None"
    environment: "dict | None"
    cancel_timeout: "int | None"
    wait_until_finished: "bool | None"
    append_job_name: "bool"
    deferrable: "bool"
    expected_terminal_state: "str | None"


class DataflowStartFlexTemplateOperator(GoogleCloudBaseOperator):
    body: "dict"
    location: "str"
    project_id: "str"
    gcp_conn_id: "str"
    drain_pipeline: "bool"
    cancel_timeout: "int | None"
    wait_until_finished: "bool | None"
    impersonation_chain: "str | Sequence[str] | None"
    deferrable: "bool"
    append_job_name: "bool"
    expected_terminal_state: "str | None"
    poll_sleep: "int"


class DataflowStartSqlJobOperator(GoogleCloudBaseOperator):
    job_name: "str"
    query: "str"
    options: "dict[str, Any]"
    location: "str"
    project_id: "str"
    gcp_conn_id: "str"
    drain_pipeline: "bool"
    impersonation_chain: "str | Sequence[str] | None"


class DataflowCreatePythonJobOperator(GoogleCloudBaseOperator):
    pass


class DataflowStopJobOperator(GoogleCloudBaseOperator):
    job_name_prefix: "str | None"
    job_id: "str | None"
    project_id: "str"
    location: "str"
    gcp_conn_id: "str"
    poll_sleep: "int"
    impersonation_chain: "str | Sequence[str] | None"
    stop_timeout: "int | None"
    drain_pipeline: "bool"


class DataflowCreatePipelineOperator(GoogleCloudBaseOperator):
    body: "dict"
    project_id: "str"
    location: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DataflowRunPipelineOperator(GoogleCloudBaseOperator):
    pipeline_name: "str"
    project_id: "str"
    location: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DataflowDeletePipelineOperator(GoogleCloudBaseOperator):
    pipeline_name: "str"
    project_id: "str"
    location: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
