# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class SalesforceToS3Operator(BaseOperator):
    salesforce_query: "str"
    s3_bucket_name: "str"
    s3_key: "str"
    salesforce_conn_id: "str"
    export_format: "str"
    query_params: "dict | None"
    include_deleted: "bool"
    coerce_to_timestamp: "bool"
    record_time_added: "bool"
    aws_conn_id: "str | None"
    replace: "bool"
    encrypt: "bool"
    gzip: "bool"
    acl_policy: "str | None"
