# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class CloudTasksQueueCreateOperator(GoogleCloudBaseOperator):
    location: "str"
    task_queue: "Queue"
    project_id: "str"
    queue_name: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudTasksQueueUpdateOperator(GoogleCloudBaseOperator):
    task_queue: "Queue"
    project_id: "str"
    location: "str | None"
    queue_name: "str | None"
    update_mask: "FieldMask | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudTasksQueueGetOperator(GoogleCloudBaseOperator):
    location: "str"
    queue_name: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudTasksQueuesListOperator(GoogleCloudBaseOperator):
    location: "str"
    project_id: "str"
    results_filter: "str | None"
    page_size: "int | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudTasksQueueDeleteOperator(GoogleCloudBaseOperator):
    location: "str"
    queue_name: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudTasksQueuePurgeOperator(GoogleCloudBaseOperator):
    location: "str"
    queue_name: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudTasksQueuePauseOperator(GoogleCloudBaseOperator):
    location: "str"
    queue_name: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudTasksQueueResumeOperator(GoogleCloudBaseOperator):
    location: "str"
    queue_name: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudTasksTaskCreateOperator(GoogleCloudBaseOperator):
    location: "str"
    queue_name: "str"
    task: "dict | Task"
    project_id: "str"
    task_name: "str | None"
    response_view: "Task.View | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudTasksTaskGetOperator(GoogleCloudBaseOperator):
    location: "str"
    queue_name: "str"
    task_name: "str"
    project_id: "str"
    response_view: "Task.View | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudTasksTasksListOperator(GoogleCloudBaseOperator):
    location: "str"
    queue_name: "str"
    project_id: "str"
    response_view: "Task.View | None"
    page_size: "int | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudTasksTaskDeleteOperator(GoogleCloudBaseOperator):
    location: "str"
    queue_name: "str"
    task_name: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudTasksTaskRunOperator(GoogleCloudBaseOperator):
    location: "str"
    queue_name: "str"
    task_name: "str"
    project_id: "str"
    response_view: "Task.View | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
