# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class CloudDataFusionPipelineStateSensor(BaseSensorOperator):
    pipeline_name: "str"
    pipeline_id: "str"
    expected_statuses: "Iterable[str]"
    instance_name: "str"
    location: "str"
    failure_statuses: "Iterable[str] | None"
    project_id: "str"
    namespace: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
