# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class DataprocJobSensor(BaseSensorOperator):
    dataproc_job_id: "str"
    region: "str"
    project_id: "str"
    gcp_conn_id: "str"
    wait_timeout: "int | None"


class DataprocBatchSensor(BaseSensorOperator):
    batch_id: "str"
    region: "str"
    project_id: "str"
    gcp_conn_id: "str"
    wait_timeout: "int | None"
