# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class BigQueryToSqlBaseOperator(BaseOperator):
    dataset_table: "str"
    target_table_name: "str | None"
    selected_fields: "list[str] | str | None"
    gcp_conn_id: "str"
    database: "str | None"
    replace: "bool"
    batch_size: "int"
    location: "str | None"
    impersonation_chain: "str | Sequence[str] | None"
    dataset_id: "str | None"
    table_id: "str | None"
