# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class FTPFileTransmitOperator(BaseOperator):
    ftp_conn_id: "str"
    local_filepath: "str | list[str]"
    remote_filepath: "str | list[str]"
    operation: "str"
    create_intermediate_dirs: "bool"


class FTPSFileTransmitOperator(FTPFileTransmitOperator):
    ftp_conn_id: "str"
    local_filepath: "str | list[str]"
    remote_filepath: "str | list[str]"
    operation: "str"
    create_intermediate_dirs: "bool"
