# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class GCSToGCSOperator(BaseOperator):
    source_bucket: "_empty"
    source_object: "_empty"
    source_objects: "_empty"
    destination_bucket: "_empty"
    destination_object: "_empty"
    delimiter: "_empty"
    move_object: "_empty"
    replace: "_empty"
    gcp_conn_id: "_empty"
    last_modified_time: "_empty"
    maximum_modified_time: "_empty"
    is_older_than: "_empty"
    impersonation_chain: "str | Sequence[str] | None"
    source_object_required: "_empty"
    exact_match: "_empty"
    match_glob: "str | None"
