# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class HivePartitionSensor(BaseSensorOperator):
    table: "str"
    partition: "str | None"
    metastore_conn_id: "str"
    schema: "str"
    poke_interval: "int"
