# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.operators.base_aws import (
    AwsBaseOperator,
)


class AthenaOperator(AwsBaseOperator):
    query: "str"
    database: "str"
    output_location: "str | None"
    client_request_token: "str | None"
    workgroup: "str"
    query_execution_context: "dict[str, str] | None"
    result_configuration: "dict[str, Any] | None"
    sleep_time: "int"
    max_polling_attempts: "int | None"
    log_query: "bool"
    deferrable: "bool"
    catalog: "str"
