# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.sensors.base_aws import AwsBaseSensor


class BedrockBaseSensor(AwsBaseSensor):
    deferrable: "bool"


class BedrockCustomizeModelCompletedSensor(BedrockBaseSensor):
    job_name: "str"
    max_retries: "int"
    poke_interval: "int"


class BedrockProvisionModelThroughputCompletedSensor(BedrockBaseSensor):
    model_id: "str"
    poke_interval: "int"
    max_retries: "int"


class BedrockKnowledgeBaseActiveSensor(BedrockBaseSensor):
    knowledge_base_id: "str"
    poke_interval: "int"
    max_retries: "int"


class BedrockIngestionJobSensor(BedrockBaseSensor):
    knowledge_base_id: "str"
    data_source_id: "str"
    ingestion_job_id: "str"
    poke_interval: "int"
    max_retries: "int"
