# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class RdsBaseSensor(BaseSensorOperator):
    aws_conn_id: "str | None"
    hook_params: "dict | None"


class RdsSnapshotExistenceSensor(RdsBaseSensor):
    db_type: "str"
    db_snapshot_identifier: "str"
    target_statuses: "list[str] | None"
    aws_conn_id: "str | None"


class RdsExportTaskExistenceSensor(RdsBaseSensor):
    export_task_identifier: "str"
    target_statuses: "list[str] | None"
    aws_conn_id: "str | None"


class RdsDbSensor(RdsBaseSensor):
    db_identifier: "str"
    db_type: "RdsDbType | str"
    target_statuses: "list[str] | None"
    aws_conn_id: "str | None"
