# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class AzureBlobStorageToGCSOperator(BaseOperator):
    wasb_conn_id: "_empty"
    gcp_conn_id: "str"
    blob_name: "str"
    container_name: "str"
    bucket_name: "str"
    object_name: "str"
    filename: "str"
    gzip: "bool"
    impersonation_chain: "str | Sequence[str] | None"
