# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class BigQueryTableExistenceSensor(BaseSensorOperator):
    project_id: "str"
    dataset_id: "str"
    table_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    deferrable: "bool"


class BigQueryTablePartitionExistenceSensor(BaseSensorOperator):
    project_id: "str"
    dataset_id: "str"
    table_id: "str"
    partition_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    deferrable: "bool"


class BigQueryTableExistenceAsyncSensor(BigQueryTableExistenceSensor):
    pass


class BigQueryTableExistencePartitionAsyncSensor(BigQueryTablePartitionExistenceSensor):
    pass
