# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class GithubOperator(BaseOperator):
    github_method: "str"
    github_conn_id: "str"
    github_method_args: "dict | None"
    result_processor: "Callable | None"
