# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class GoogleAnalyticsListAccountsOperator(BaseOperator):
    pass


class GoogleAnalyticsGetAdsLinkOperator(BaseOperator):
    pass


class GoogleAnalyticsRetrieveAdsLinksListOperator(BaseOperator):
    pass


class GoogleAnalyticsDataImportUploadOperator(BaseOperator):
    pass


class GoogleAnalyticsDeletePreviousDataUploadsOperator(BaseOperator):
    pass


class GoogleAnalyticsModifyFileHeadersDataImportOperator(BaseOperator):
    storage_bucket: "str"
    storage_name_object: "str"
    gcp_conn_id: "str"
    delegate_to: "str | None"
    custom_dimension_header_mapping: "dict[str, str] | None"
    impersonation_chain: "str | Sequence[str] | None"
