# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class WasbDeleteBlobOperator(BaseOperator):
    container_name: "str"
    blob_name: "str"
    wasb_conn_id: "str"
    check_options: "Any"
    is_prefix: "bool"
    ignore_if_missing: "bool"
