# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.operators.base_aws import (
    AwsBaseOperator,
)


class GlueCrawlerOperator(AwsBaseOperator):
    config: "_empty"
    poll_interval: "int"
    wait_for_completion: "bool"
    deferrable: "bool"
