# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class CloudMemorystoreCreateInstanceOperator(GoogleCloudBaseOperator):
    location: "str"
    instance_id: "str"
    instance: "dict | Instance"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudMemorystoreDeleteInstanceOperator(GoogleCloudBaseOperator):
    location: "str"
    instance: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudMemorystoreExportInstanceOperator(GoogleCloudBaseOperator):
    location: "str"
    instance: "str"
    output_config: "dict | OutputConfig"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudMemorystoreFailoverInstanceOperator(GoogleCloudBaseOperator):
    location: "str"
    instance: "str"
    data_protection_mode: "FailoverInstanceRequest.DataProtectionMode"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudMemorystoreGetInstanceOperator(GoogleCloudBaseOperator):
    location: "str"
    instance: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudMemorystoreImportOperator(GoogleCloudBaseOperator):
    location: "str"
    instance: "str"
    input_config: "dict | InputConfig"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudMemorystoreListInstancesOperator(GoogleCloudBaseOperator):
    location: "str"
    page_size: "int"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudMemorystoreUpdateInstanceOperator(GoogleCloudBaseOperator):
    update_mask: "dict | FieldMask"
    instance: "dict | Instance"
    location: "str | None"
    instance_id: "str | None"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudMemorystoreScaleInstanceOperator(GoogleCloudBaseOperator):
    memory_size_gb: "int"
    location: "str | None"
    instance_id: "str | None"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudMemorystoreCreateInstanceAndImportOperator(GoogleCloudBaseOperator):
    location: "str"
    instance_id: "str"
    instance: "dict | Instance"
    input_config: "dict | InputConfig"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudMemorystoreExportAndDeleteInstanceOperator(GoogleCloudBaseOperator):
    location: "str"
    instance: "str"
    output_config: "dict | OutputConfig"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudMemorystoreMemcachedApplyParametersOperator(GoogleCloudBaseOperator):
    node_ids: "Sequence[str]"
    apply_all: "bool"
    location: "str"
    instance_id: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudMemorystoreMemcachedCreateInstanceOperator(GoogleCloudBaseOperator):
    location: "str"
    instance_id: "str"
    instance: "dict | cloud_memcache.Instance"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"


class CloudMemorystoreMemcachedDeleteInstanceOperator(GoogleCloudBaseOperator):
    location: "str"
    instance: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"


class CloudMemorystoreMemcachedGetInstanceOperator(GoogleCloudBaseOperator):
    location: "str"
    instance: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudMemorystoreMemcachedListInstancesOperator(GoogleCloudBaseOperator):
    location: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudMemorystoreMemcachedUpdateInstanceOperator(GoogleCloudBaseOperator):
    update_mask: "dict | FieldMask"
    instance: "dict | cloud_memcache.Instance"
    location: "str | None"
    instance_id: "str | None"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudMemorystoreMemcachedUpdateParametersOperator(GoogleCloudBaseOperator):
    update_mask: "dict | FieldMask"
    parameters: "dict | cloud_memcache.MemcacheParameters"
    location: "str"
    instance_id: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
