# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.operators.base_aws import (
    AwsBaseOperator,
)


class LambdaCreateFunctionOperator(AwsBaseOperator):
    function_name: "str"
    runtime: "str | None"
    role: "str"
    handler: "str | None"
    code: "dict"
    description: "str | None"
    timeout: "int | None"
    config: "dict | None"
    wait_for_completion: "bool"
    waiter_max_attempts: "int"
    waiter_delay: "int"
    deferrable: "bool"


class LambdaInvokeFunctionOperator(AwsBaseOperator):
    function_name: "str"
    log_type: "str | None"
    keep_empty_log_lines: "bool"
    qualifier: "str | None"
    invocation_type: "str | None"
    client_context: "str | None"
    payload: "bytes | str | None"
