# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class _CreateDatabricksWorkflowOperator(BaseOperator):
    task_id: "str"
    databricks_conn_id: "str"
    existing_clusters: "list[str] | None"
    extra_job_params: "dict[str, Any] | None"
    job_clusters: "list[dict[str, object]] | None"
    max_concurrent_runs: "int"
    notebook_params: "dict | None"
    tasks_to_convert: "list[BaseOperator] | None"
