# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class AzureDataFactoryRunPipelineOperator(BaseOperator):
    pipeline_name: "str"
    azure_data_factory_conn_id: "str"
    resource_group_name: "str"
    factory_name: "str"
    wait_for_termination: "bool"
    reference_pipeline_run_id: "str | None"
    is_recovery: "bool | None"
    start_activity_name: "str | None"
    start_from_failure: "bool | None"
    parameters: "dict[str, Any] | None"
    timeout: "int"
    check_interval: "int"
    deferrable: "bool"
