# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.decorators.python import _PythonDecoratedOperator
from airfly._vendor.airflow.operators.python import PythonVirtualenvOperator


class _PythonVirtualenvDecoratedOperator(
    _PythonDecoratedOperator, PythonVirtualenvOperator
):
    python_callable: "_empty"
    op_args: "_empty"
    op_kwargs: "_empty"
