# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class RedisPubSubSensor(BaseSensorOperator):
    channels: "list[str] | str"
    redis_conn_id: "str"
