# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.cncf.kubernetes.operators.job import (
    KubernetesDeleteJobOperator,
    KubernetesJobOperator,
)
from airfly._vendor.airflow.providers.cncf.kubernetes.operators.pod import (
    KubernetesPodOperator,
)
from airfly._vendor.airflow.providers.cncf.kubernetes.operators.resource import (
    KubernetesCreateResourceOperator,
    KubernetesDeleteResourceOperator,
)
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class GKEDeleteClusterOperator(GoogleCloudBaseOperator):
    name: "str"
    location: "str"
    project_id: "str"
    gcp_conn_id: "str"
    api_version: "str"
    impersonation_chain: "str | Sequence[str] | None"
    deferrable: "bool"
    poll_interval: "int"


class GKECreateClusterOperator(GoogleCloudBaseOperator):
    location: "str"
    body: "dict | Cluster"
    project_id: "str"
    gcp_conn_id: "str"
    api_version: "str"
    impersonation_chain: "str | Sequence[str] | None"
    poll_interval: "int"
    deferrable: "bool"


class GKEStartKueueInsideClusterOperator(GoogleCloudBaseOperator):
    location: "str"
    cluster_name: "str"
    kueue_version: "str"
    use_internal_ip: "bool"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class GKEStartPodOperator(KubernetesPodOperator):
    location: "str"
    cluster_name: "str"
    use_internal_ip: "bool"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    regional: "bool | None"
    on_finish_action: "str | None"
    is_delete_operator_pod: "bool | None"


class GKEStartJobOperator(KubernetesJobOperator):
    location: "str"
    cluster_name: "str"
    use_internal_ip: "bool"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    deferrable: "bool"
    job_poll_interval: "float"


class GKEDescribeJobOperator(GoogleCloudBaseOperator):
    job_name: "str"
    location: "str"
    namespace: "str"
    cluster_name: "str"
    project_id: "str"
    use_internal_ip: "bool"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class GKEListJobsOperator(GoogleCloudBaseOperator):
    location: "str"
    cluster_name: "str"
    namespace: "str | None"
    project_id: "str"
    use_internal_ip: "bool"
    do_xcom_push: "bool"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class GKECreateCustomResourceOperator(KubernetesCreateResourceOperator):
    location: "str"
    cluster_name: "str"
    use_internal_ip: "bool"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class GKEDeleteCustomResourceOperator(KubernetesDeleteResourceOperator):
    location: "str"
    cluster_name: "str"
    use_internal_ip: "bool"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class GKEStartKueueJobOperator(GKEStartJobOperator):
    queue_name: "str"


class GKEDeleteJobOperator(KubernetesDeleteJobOperator):
    location: "str"
    cluster_name: "str"
    use_internal_ip: "bool"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class GKESuspendJobOperator(GoogleCloudBaseOperator):
    name: "str"
    location: "str"
    namespace: "str"
    cluster_name: "str"
    project_id: "str"
    use_internal_ip: "bool"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class GKEResumeJobOperator(GoogleCloudBaseOperator):
    name: "str"
    location: "str"
    namespace: "str"
    cluster_name: "str"
    project_id: "str"
    use_internal_ip: "bool"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
