# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.docker.operators.docker import DockerOperator


class DockerSwarmOperator(DockerOperator):
    image: "str"
    args: "str | list[str] | None"
    enable_logging: "bool"
    configs: "list[types.ConfigReference] | None"
    secrets: "list[types.SecretReference] | None"
    mode: "types.ServiceMode | None"
    networks: "list[str | types.NetworkAttachmentConfig] | None"
    placement: "types.Placement | list[types.Placement] | None"
    container_resources: "types.Resources | None"
