# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class DeleteModelOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    model_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class GetModelOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    model_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class ExportModelOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    model_id: "str"
    output_config: "model_service.ExportModelRequest.OutputConfig | dict"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class ListModelsOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    filter: "str | None"
    page_size: "int | None"
    page_token: "str | None"
    read_mask: "str | None"
    order_by: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class UploadModelOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    model: "Model | dict"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class ListModelVersionsOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    model_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class SetDefaultVersionOnModelOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    model_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class AddVersionAliasesOnModelOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    model_id: "str"
    version_aliases: "Sequence[str]"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DeleteVersionAliasesOnModelOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    model_id: "str"
    version_aliases: "Sequence[str]"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DeleteModelVersionOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    model_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
