# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class DataprocMetastoreCreateBackupOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    service_id: "str"
    backup: "dict | Backup"
    backup_id: "str"
    request_id: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DataprocMetastoreCreateMetadataImportOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    service_id: "str"
    metadata_import: "dict | MetadataImport"
    metadata_import_id: "str"
    request_id: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DataprocMetastoreCreateServiceOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    service: "dict | Service"
    service_id: "str"
    request_id: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DataprocMetastoreDeleteBackupOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    service_id: "str"
    backup_id: "str"
    request_id: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DataprocMetastoreDeleteServiceOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    service_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DataprocMetastoreExportMetadataOperator(GoogleCloudBaseOperator):
    destination_gcs_folder: "str"
    project_id: "str"
    region: "str"
    service_id: "str"
    request_id: "str | None"
    database_dump_type: "DatabaseDumpSpec | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DataprocMetastoreGetServiceOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    service_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DataprocMetastoreListBackupsOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    service_id: "str"
    page_size: "int | None"
    page_token: "str | None"
    filter: "str | None"
    order_by: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DataprocMetastoreRestoreServiceOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    service_id: "str"
    backup_project_id: "str"
    backup_region: "str"
    backup_service_id: "str"
    backup_id: "str"
    restore_type: "Restore | None"
    request_id: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DataprocMetastoreUpdateServiceOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    service_id: "str"
    service: "dict | Service"
    update_mask: "FieldMask"
    request_id: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
