# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class DecoratedOperator(BaseOperator):
    python_callable: "Callable"
    task_id: "str"
    op_args: "Collection[Any] | None"
    op_kwargs: "Mapping[str, Any] | None"
    kwargs_to_upstream: "dict[str, Any] | None"
