# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.sensors.base_aws import AwsBaseSensor


class ComprehendBaseSensor(AwsBaseSensor):
    deferrable: "bool"


class ComprehendStartPiiEntitiesDetectionJobCompletedSensor(ComprehendBaseSensor):
    job_id: "str"
    max_retries: "int"
    poke_interval: "int"


class ComprehendCreateDocumentClassifierCompletedSensor(AwsBaseSensor):
    document_classifier_arn: "str"
    fail_on_warnings: "bool"
    max_retries: "int"
    poke_interval: "int"
    deferrable: "bool"
    aws_conn_id: "str | None"
