# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class TelegramOperator(BaseOperator):
    telegram_conn_id: "str"
    token: "str | None"
    chat_id: "str | None"
    text: "str"
    telegram_kwargs: "dict | None"
