# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class CloudDataCatalogCreateEntryOperator(GoogleCloudBaseOperator):
    location: "str"
    entry_group: "str"
    entry_id: "str"
    entry: "dict | Entry"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataCatalogCreateEntryGroupOperator(GoogleCloudBaseOperator):
    location: "str"
    entry_group_id: "str"
    entry_group: "dict | EntryGroup"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataCatalogCreateTagOperator(GoogleCloudBaseOperator):
    location: "str"
    entry_group: "str"
    entry: "str"
    tag: "dict | Tag"
    template_id: "str | None"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataCatalogCreateTagTemplateOperator(GoogleCloudBaseOperator):
    location: "str"
    tag_template_id: "str"
    tag_template: "dict | TagTemplate"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataCatalogCreateTagTemplateFieldOperator(GoogleCloudBaseOperator):
    location: "str"
    tag_template: "str"
    tag_template_field_id: "str"
    tag_template_field: "dict | TagTemplateField"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataCatalogDeleteEntryOperator(GoogleCloudBaseOperator):
    location: "str"
    entry_group: "str"
    entry: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataCatalogDeleteEntryGroupOperator(GoogleCloudBaseOperator):
    location: "str"
    entry_group: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataCatalogDeleteTagOperator(GoogleCloudBaseOperator):
    location: "str"
    entry_group: "str"
    entry: "str"
    tag: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataCatalogDeleteTagTemplateOperator(GoogleCloudBaseOperator):
    location: "str"
    tag_template: "str"
    force: "bool"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataCatalogDeleteTagTemplateFieldOperator(GoogleCloudBaseOperator):
    location: "str"
    tag_template: "str"
    field: "str"
    force: "bool"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataCatalogGetEntryOperator(GoogleCloudBaseOperator):
    location: "str"
    entry_group: "str"
    entry: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataCatalogGetEntryGroupOperator(GoogleCloudBaseOperator):
    location: "str"
    entry_group: "str"
    read_mask: "FieldMask"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataCatalogGetTagTemplateOperator(GoogleCloudBaseOperator):
    location: "str"
    tag_template: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataCatalogListTagsOperator(GoogleCloudBaseOperator):
    location: "str"
    entry_group: "str"
    entry: "str"
    page_size: "int"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataCatalogLookupEntryOperator(GoogleCloudBaseOperator):
    linked_resource: "str | None"
    sql_resource: "str | None"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataCatalogRenameTagTemplateFieldOperator(GoogleCloudBaseOperator):
    location: "str"
    tag_template: "str"
    field: "str"
    new_tag_template_field_id: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataCatalogSearchCatalogOperator(GoogleCloudBaseOperator):
    scope: "dict | SearchCatalogRequest.Scope"
    query: "str"
    page_size: "int"
    order_by: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataCatalogUpdateEntryOperator(GoogleCloudBaseOperator):
    entry: "dict | Entry"
    update_mask: "dict | FieldMask"
    location: "str | None"
    entry_group: "str | None"
    entry_id: "str | None"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataCatalogUpdateTagOperator(GoogleCloudBaseOperator):
    tag: "dict | Tag"
    update_mask: "dict | FieldMask"
    location: "str | None"
    entry_group: "str | None"
    entry: "str | None"
    tag_id: "str | None"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataCatalogUpdateTagTemplateOperator(GoogleCloudBaseOperator):
    tag_template: "dict | TagTemplate"
    update_mask: "dict | FieldMask"
    location: "str | None"
    tag_template_id: "str | None"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataCatalogUpdateTagTemplateFieldOperator(GoogleCloudBaseOperator):
    tag_template_field: "dict | TagTemplateField"
    update_mask: "dict | FieldMask"
    tag_template_field_name: "str | None"
    location: "str | None"
    tag_template: "str | None"
    tag_template_field_id: "str | None"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
