# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.utils.mixins import AwsBaseHookMixin
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class AwsBaseSensor(BaseSensorOperator, AwsBaseHookMixin):
    aws_conn_id: "str | None"
    region_name: "str | None"
    verify: "bool | str | None"
    botocore_config: "dict | None"
    region: "str | None | ArgNotSet"
