# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class OpenSearchQueryOperator(BaseOperator):
    query: "dict | None"
    search_object: "Any | None"
    index_name: "str | None"
    opensearch_conn_id: "str"
    opensearch_conn_class: "type[OpenSearchConnectionClass] | None"
    log_query: "bool"


class OpenSearchCreateIndexOperator(BaseOperator):
    index_name: "str"
    index_body: "dict[str, Any]"
    opensearch_conn_id: "str"


class OpenSearchAddDocumentOperator(BaseOperator):
    index_name: "str | None"
    document: "dict[str, Any] | None"
    doc_id: "int | None"
    doc_class: "Any | None"
    opensearch_conn_id: "str"
