# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.operators.base_aws import (
    AwsBaseOperator,
)


class NeptuneStartDbClusterOperator(AwsBaseOperator):
    db_cluster_id: "str"
    wait_for_completion: "bool"
    waiter_delay: "int"
    waiter_max_attempts: "int"
    deferrable: "bool"


class NeptuneStopDbClusterOperator(AwsBaseOperator):
    db_cluster_id: "str"
    wait_for_completion: "bool"
    waiter_delay: "int"
    waiter_max_attempts: "int"
    deferrable: "bool"
