# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class KubernetesPodOperator(BaseOperator):
    kubernetes_conn_id: "str | None"
    namespace: "str | None"
    image: "str | None"
    name: "str | None"
    random_name_suffix: "bool"
    cmds: "list[str] | None"
    arguments: "list[str] | None"
    ports: "list[k8s.V1ContainerPort] | None"
    volume_mounts: "list[k8s.V1VolumeMount] | None"
    volumes: "list[k8s.V1Volume] | None"
    env_vars: "list[k8s.V1EnvVar] | dict[str, str] | None"
    env_from: "list[k8s.V1EnvFromSource] | None"
    secrets: "list[Secret] | None"
    in_cluster: "bool | None"
    cluster_context: "str | None"
    labels: "dict | None"
    reattach_on_restart: "bool"
    startup_timeout_seconds: "int"
    startup_check_interval_seconds: "int"
    get_logs: "bool"
    container_logs: "Iterable[str] | str | Literal[True]"
    image_pull_policy: "str | None"
    annotations: "dict | None"
    container_resources: "k8s.V1ResourceRequirements | None"
    affinity: "k8s.V1Affinity | None"
    config_file: "str | None"
    node_selector: "dict | None"
    image_pull_secrets: "list[k8s.V1LocalObjectReference] | None"
    service_account_name: "str | None"
    hostnetwork: "bool"
    host_aliases: "list[k8s.V1HostAlias] | None"
    tolerations: "list[k8s.V1Toleration] | None"
    security_context: "k8s.V1PodSecurityContext | dict | None"
    container_security_context: "k8s.V1SecurityContext | dict | None"
    dnspolicy: "str | None"
    dns_config: "k8s.V1PodDNSConfig | None"
    hostname: "str | None"
    subdomain: "str | None"
    schedulername: "str | None"
    full_pod_spec: "k8s.V1Pod | None"
    init_containers: "list[k8s.V1Container] | None"
    log_events_on_failure: "bool"
    do_xcom_push: "bool"
    pod_template_file: "str | None"
    pod_template_dict: "dict | None"
    priority_class_name: "str | None"
    pod_runtime_info_envs: "list[k8s.V1EnvVar] | None"
    termination_grace_period: "int | None"
    configmaps: "list[str] | None"
    skip_on_exit_code: "int | Container[int] | None"
    base_container_name: "str | None"
    deferrable: "bool"
    poll_interval: "float"
    log_pod_spec_on_failure: "bool"
    on_finish_action: "str"
    is_delete_operator_pod: "None | bool"
    termination_message_policy: "str"
    active_deadline_seconds: "int | None"
    callbacks: "type[KubernetesPodOperatorCallback] | None"
    progress_callback: "Callable[[str], None] | None"
    logging_interval: "int | None"
