# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class AzureDataExplorerQueryOperator(BaseOperator):
    query: "str"
    database: "str"
    options: "dict | None"
    azure_data_explorer_conn_id: "str"
