# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class ADLSListOperator(BaseOperator):
    path: "str"
    azure_data_lake_conn_id: "str"


class ADLSCreateObjectOperator(BaseOperator):
    file_system_name: "str"
    file_name: "str"
    data: "bytes | str | Iterable[AnyStr] | IO[AnyStr]"
    length: "int | None"
    replace: "bool"
    azure_data_lake_conn_id: "str"


class ADLSDeleteOperator(BaseOperator):
    path: "str"
    recursive: "bool"
    ignore_not_found: "bool"
    azure_data_lake_conn_id: "str"
