# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class SqlSensor(BaseSensorOperator):
    conn_id: "str"
    sql: "str"
    parameters: "Mapping[str, Any] | None"
    success: "Callable[[Any], bool] | None"
    failure: "Callable[[Any], bool] | None"
    fail_on_empty: "bool"
    hook_params: "Mapping[str, Any] | None"
