# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.transfers.bigquery_to_sql import (
    BigQueryToSqlBaseOperator,
)


class BigQueryToMySqlOperator(BigQueryToSqlBaseOperator):
    mysql_table: "str | None"
    target_table_name: "str | None"
    mysql_conn_id: "str"
    dataset_id: "str | None"
    table_id: "str | None"
