# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class AsanaCreateTaskOperator(BaseOperator):
    conn_id: "str"
    name: "str"
    task_parameters: "dict | None"


class AsanaUpdateTaskOperator(BaseOperator):
    conn_id: "str"
    asana_task_gid: "str"
    task_parameters: "dict"


class AsanaDeleteTaskOperator(BaseOperator):
    conn_id: "str"
    asana_task_gid: "str"


class AsanaFindTaskOperator(BaseOperator):
    conn_id: "str"
    search_parameters: "dict | None"
