# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class OpenAIEmbeddingOperator(BaseOperator):
    conn_id: "str"
    input_text: "str | list[str] | list[int] | list[list[int]]"
    model: "str"
    embedding_kwargs: "dict | None"
