# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class SparkSubmitOperator(BaseOperator):
    application: "str"
    conf: "dict[str, Any] | None"
    conn_id: "str"
    files: "str | None"
    py_files: "str | None"
    archives: "str | None"
    driver_class_path: "str | None"
    jars: "str | None"
    java_class: "str | None"
    packages: "str | None"
    exclude_packages: "str | None"
    repositories: "str | None"
    total_executor_cores: "int | None"
    executor_cores: "int | None"
    executor_memory: "str | None"
    driver_memory: "str | None"
    keytab: "str | None"
    principal: "str | None"
    proxy_user: "str | None"
    name: "str"
    num_executors: "int | None"
    status_poll_interval: "int"
    application_args: "list[Any] | None"
    env_vars: "dict[str, Any] | None"
    verbose: "bool"
    spark_binary: "str | None"
    properties_file: "str | None"
    yarn_queue: "str | None"
    deploy_mode: "str | None"
    use_krb5ccache: "bool"
