# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class PsrpOperator(BaseOperator):
    psrp_conn_id: "str"
    command: "str | None"
    powershell: "str | None"
    cmdlet: "str | None"
    arguments: "list[str] | None"
    parameters: "dict[str, str] | None"
    logging_level: "int"
    runspace_options: "dict[str, Any] | None"
    wsman_options: "dict[str, Any] | None"
    psrp_session_init: "Command | None"
