# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator
from airfly._vendor.airflow.providers.cncf.kubernetes.operators.pod import (
    KubernetesPodOperator,
)


class KubernetesJobOperator(KubernetesPodOperator):
    job_template_file: "str | None"
    full_job_spec: "k8s.V1Job | None"
    backoff_limit: "int | None"
    completion_mode: "str | None"
    completions: "int | None"
    manual_selector: "bool | None"
    parallelism: "int | None"
    selector: "k8s.V1LabelSelector | None"
    suspend: "bool | None"
    ttl_seconds_after_finished: "int | None"
    wait_until_job_complete: "bool"
    job_poll_interval: "float"
    deferrable: "bool"


class KubernetesDeleteJobOperator(BaseOperator):
    name: "str"
    namespace: "str"
    kubernetes_conn_id: "str | None"
    config_file: "str | None"
    in_cluster: "bool | None"
    cluster_context: "str | None"
    delete_on_status: "str | None"
    wait_for_completion: "bool"
    poll_interval: "float"


class KubernetesPatchJobOperator(BaseOperator):
    name: "str"
    namespace: "str"
    body: "object"
    kubernetes_conn_id: "str | None"
    config_file: "str | None"
    in_cluster: "bool | None"
    cluster_context: "str | None"
