# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class GoogleDriveFileExistenceSensor(BaseSensorOperator):
    folder_id: "str"
    file_name: "str"
    drive_id: "str | None"
    gcp_conn_id: "str"
    delegate_to: "str | None"
    impersonation_chain: "str | Sequence[str] | None"
