# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.sensors.base_aws import AwsBaseSensor


class CloudFormationCreateStackSensor(AwsBaseSensor):
    stack_name: "_empty"


class CloudFormationDeleteStackSensor(AwsBaseSensor):
    stack_name: "str"
    aws_conn_id: "str | None"
    region_name: "str | None"
