# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class MLEngineStartBatchPredictionJobOperator(GoogleCloudBaseOperator):
    pass


class MLEngineManageModelOperator(GoogleCloudBaseOperator):
    pass


class MLEngineCreateModelOperator(GoogleCloudBaseOperator):
    pass


class MLEngineGetModelOperator(GoogleCloudBaseOperator):
    pass


class MLEngineDeleteModelOperator(GoogleCloudBaseOperator):
    pass


class MLEngineManageVersionOperator(GoogleCloudBaseOperator):
    pass


class MLEngineCreateVersionOperator(GoogleCloudBaseOperator):
    pass


class MLEngineSetDefaultVersionOperator(GoogleCloudBaseOperator):
    pass


class MLEngineListVersionsOperator(GoogleCloudBaseOperator):
    pass


class MLEngineDeleteVersionOperator(GoogleCloudBaseOperator):
    pass


class MLEngineStartTrainingJobOperator(GoogleCloudBaseOperator):
    pass


class MLEngineTrainingCancelJobOperator(GoogleCloudBaseOperator):
    pass
