# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class SpannerDeployInstanceOperator(GoogleCloudBaseOperator):
    instance_id: "str"
    configuration_name: "str"
    node_count: "int"
    display_name: "str"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class SpannerDeleteInstanceOperator(GoogleCloudBaseOperator):
    instance_id: "str"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class SpannerQueryDatabaseInstanceOperator(GoogleCloudBaseOperator):
    instance_id: "str"
    database_id: "str"
    query: "str | list[str]"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class SpannerDeployDatabaseInstanceOperator(GoogleCloudBaseOperator):
    instance_id: "str"
    database_id: "str"
    ddl_statements: "list[str]"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class SpannerUpdateDatabaseInstanceOperator(GoogleCloudBaseOperator):
    instance_id: "str"
    database_id: "str"
    ddl_statements: "list[str]"
    project_id: "str"
    operation_id: "str | None"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class SpannerDeleteDatabaseInstanceOperator(GoogleCloudBaseOperator):
    instance_id: "str"
    database_id: "str"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
