# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class ProduceToTopicOperator(BaseOperator):
    topic: "str"
    producer_function: "str | Callable[..., Any]"
    kafka_config_id: "str"
    producer_function_args: "Sequence[Any] | None"
    producer_function_kwargs: "dict[Any, Any] | None"
    delivery_callback: "str | None"
    synchronous: "bool"
    poll_timeout: "float"
