# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.microsoft.azure.operators.adls import (
    ADLSListOperator,
)


class ADLSToGCSOperator(ADLSListOperator):
    src_adls: "str"
    dest_gcs: "str"
    azure_data_lake_conn_id: "str"
    gcp_conn_id: "str"
    replace: "bool"
    gzip: "bool"
    google_impersonation_chain: "str | Sequence[str] | None"
