# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.operators.base_aws import (
    AwsBaseOperator,
)


class StepFunctionStartExecutionOperator(AwsBaseOperator):
    state_machine_arn: "str"
    name: "str | None"
    is_redrive_execution: "bool"
    state_machine_input: "dict | str | None"
    waiter_max_attempts: "int"
    waiter_delay: "int"
    deferrable: "bool"


class StepFunctionGetExecutionOutputOperator(AwsBaseOperator):
    execution_arn: "str"
