# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class HiveOperator(BaseOperator):
    hql: "str"
    hive_cli_conn_id: "str"
    schema: "str"
    hiveconfs: "dict[Any, Any] | None"
    hiveconf_jinja_translate: "bool"
    script_begin_tag: "str | None"
    mapred_queue: "str | None"
    mapred_queue_priority: "str | None"
    mapred_job_name: "str | None"
    hive_cli_params: "str"
    auth: "str | None"
    proxy_user: "str | None"
