# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.dataflow import (
    DataflowCreatePipelineOperator,
    DataflowRunPipelineOperator,
)


class CreateDataPipelineOperator(DataflowCreatePipelineOperator):
    pass


class RunDataPipelineOperator(DataflowRunPipelineOperator):
    pass
