# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class DataformWorkflowInvocationStateSensor(BaseSensorOperator):
    project_id: "str"
    region: "str"
    repository_id: "str"
    workflow_invocation_id: "str"
    expected_statuses: "set[int] | int"
    failure_statuses: "Iterable[int] | None"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
