# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.sensors.base_aws import AwsBaseSensor


class EcsBaseSensor(AwsBaseSensor):
    aws_conn_id: "str | None"
    region_name: "str | None"
    verify: "bool | str | None"
    botocore_config: "dict | None"
    region: "str | None | ArgNotSet"


class EcsClusterStateSensor(EcsBaseSensor):
    cluster_name: "str"
    target_state: "EcsClusterStates | None"
    failure_states: "set[EcsClusterStates] | None"


class EcsTaskDefinitionStateSensor(EcsBaseSensor):
    task_definition: "str"
    target_state: "EcsTaskDefinitionStates | None"


class EcsTaskStateSensor(EcsBaseSensor):
    cluster: "str"
    task: "str"
    target_state: "EcsTaskStates | None"
    failure_states: "set[EcsTaskStates] | None"
