# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class MetastoreHivePartitionSensor(BaseSensorOperator):
    service_id: "str"
    region: "str"
    table: "str"
    partitions: "list[str] | None"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
