# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class DataprepGetJobsForJobGroupOperator(GoogleCloudBaseOperator):
    dataprep_conn_id: "str"
    job_group_id: "int | str"


class DataprepGetJobGroupOperator(GoogleCloudBaseOperator):
    dataprep_conn_id: "str"
    project_id: "str"
    job_group_id: "int | str"
    embed: "str"
    include_deleted: "bool"


class DataprepRunJobGroupOperator(GoogleCloudBaseOperator):
    project_id: "str"
    dataprep_conn_id: "str"
    body_request: "dict"


class DataprepCopyFlowOperator(GoogleCloudBaseOperator):
    project_id: "str"
    dataprep_conn_id: "str"
    flow_id: "int | str"
    name: "str"
    description: "str"
    copy_datasources: "bool"


class DataprepDeleteFlowOperator(GoogleCloudBaseOperator):
    dataprep_conn_id: "str"
    flow_id: "int | str"


class DataprepRunFlowOperator(GoogleCloudBaseOperator):
    project_id: "str"
    flow_id: "int | str"
    body_request: "dict"
    dataprep_conn_id: "str"
