# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class PromptLanguageModelOperator(GoogleCloudBaseOperator):
    pass


class GenerateTextEmbeddingsOperator(GoogleCloudBaseOperator):
    pass


class PromptMultimodalModelOperator(GoogleCloudBaseOperator):
    pass


class PromptMultimodalModelWithMediaOperator(GoogleCloudBaseOperator):
    pass


class TextGenerationModelPredictOperator(GoogleCloudBaseOperator):
    project_id: "str"
    location: "str"
    prompt: "str"
    pretrained_model: "str"
    temperature: "float"
    max_output_tokens: "int"
    top_p: "float"
    top_k: "int"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class TextEmbeddingModelGetEmbeddingsOperator(GoogleCloudBaseOperator):
    project_id: "str"
    location: "str"
    prompt: "str"
    pretrained_model: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class GenerativeModelGenerateContentOperator(GoogleCloudBaseOperator):
    project_id: "str"
    contents: "list"
    location: "str"
    tools: "list | None"
    generation_config: "dict | None"
    safety_settings: "dict | None"
    pretrained_model: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
