# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class LifeSciencesRunPipelineOperator(GoogleCloudBaseOperator):
    pass
