# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.transfers.azure_blob_to_gcs import (
    AzureBlobStorageToGCSOperator,
)


class AzureBlobStorageToGCSOperator(AzureBlobStorageToGCSOperator):
    pass
