# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class GoogleCampaignManagerDeleteReportOperator(BaseOperator):
    profile_id: "str"
    report_name: "str | None"
    report_id: "str | None"
    api_version: "str"
    gcp_conn_id: "str"
    delegate_to: "str | None"
    impersonation_chain: "str | Sequence[str] | None"


class GoogleCampaignManagerDownloadReportOperator(BaseOperator):
    profile_id: "str"
    report_id: "str"
    file_id: "str"
    bucket_name: "str"
    report_name: "str | None"
    gzip: "bool"
    chunk_size: "int"
    api_version: "str"
    gcp_conn_id: "str"
    delegate_to: "str | None"
    impersonation_chain: "str | Sequence[str] | None"


class GoogleCampaignManagerInsertReportOperator(BaseOperator):
    profile_id: "str"
    report: "dict[str, Any]"
    api_version: "str"
    gcp_conn_id: "str"
    delegate_to: "str | None"
    impersonation_chain: "str | Sequence[str] | None"


class GoogleCampaignManagerRunReportOperator(BaseOperator):
    profile_id: "str"
    report_id: "str"
    synchronous: "bool"
    api_version: "str"
    gcp_conn_id: "str"
    delegate_to: "str | None"
    impersonation_chain: "str | Sequence[str] | None"


class GoogleCampaignManagerBatchInsertConversionsOperator(BaseOperator):
    profile_id: "str"
    conversions: "list[dict[str, Any]]"
    encryption_entity_type: "str"
    encryption_entity_id: "int"
    encryption_source: "str"
    max_failed_inserts: "int"
    api_version: "str"
    gcp_conn_id: "str"
    delegate_to: "str | None"
    impersonation_chain: "str | Sequence[str] | None"


class GoogleCampaignManagerBatchUpdateConversionsOperator(BaseOperator):
    profile_id: "str"
    conversions: "list[dict[str, Any]]"
    encryption_entity_type: "str"
    encryption_entity_id: "int"
    encryption_source: "str"
    max_failed_updates: "int"
    api_version: "str"
    gcp_conn_id: "str"
    delegate_to: "str | None"
    impersonation_chain: "str | Sequence[str] | None"
