# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class GithubSensor(BaseSensorOperator):
    method_name: "str"
    github_conn_id: "str"
    method_params: "dict | None"
    result_processor: "Callable | None"


class BaseGithubRepositorySensor(GithubSensor):
    github_conn_id: "str"
    repository_name: "str | None"
    result_processor: "Callable | None"


class GithubTagSensor(BaseGithubRepositorySensor):
    github_conn_id: "str"
    tag_name: "str | None"
    repository_name: "str | None"
