# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class SSHOperator(BaseOperator):
    ssh_hook: "SSHHook | None"
    ssh_conn_id: "str | None"
    remote_host: "str | None"
    command: "str | None"
    conn_timeout: "int | None"
    cmd_timeout: "int | ArgNotSet | None"
    environment: "dict | None"
    get_pty: "bool"
    banner_timeout: "float"
    skip_on_exit_code: "int | Container[int] | None"
