# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class SparkSqlOperator(BaseOperator):
    sql: "str"
    conf: "str | None"
    conn_id: "str"
    total_executor_cores: "int | None"
    executor_cores: "int | None"
    executor_memory: "str | None"
    keytab: "str | None"
    principal: "str | None"
    master: "str | None"
    name: "str"
    num_executors: "int | None"
    verbose: "bool"
    yarn_queue: "str | None"
