# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class S3ToFTPOperator(BaseOperator):
    s3_bucket: "_empty"
    s3_key: "_empty"
    ftp_path: "_empty"
    aws_conn_id: "_empty"
    ftp_conn_id: "_empty"
