# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.sensors.base_aws import AwsBaseSensor


class StepFunctionExecutionSensor(AwsBaseSensor):
    execution_arn: "str"
