# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class WeaviateIngestOperator(BaseOperator):
    conn_id: "str"
    collection_name: "str"
    input_data: "list[dict[str, Any]] | pd.DataFrame | None"
    vector_col: "str"
    uuid_column: "str"
    tenant: "str | None"
    hook_params: "dict | None"
    input_json: "list[dict[str, Any]] | pd.DataFrame | None"


class WeaviateDocumentIngestOperator(BaseOperator):
    conn_id: "str"
    input_data: "pd.DataFrame | list[dict[str, Any]] | list[pd.DataFrame]"
    collection_name: "str"
    document_column: "str"
    existing: "str"
    uuid_column: "str"
    vector_col: "str"
    tenant: "str | None"
    verbose: "bool"
    hook_params: "dict | None"
