# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.operators.empty import EmptyOperator
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class ExternalTaskMarker(EmptyOperator):
    external_dag_id: "str"
    external_task_id: "str"
    execution_date: "str | datetime.datetime | None"
    recursion_depth: "int"


class ExternalTaskSensor(BaseSensorOperator):
    external_dag_id: "str"
    external_task_id: "str | None"
    external_task_ids: "Collection[str] | None"
    external_task_group_id: "str | None"
    allowed_states: "Iterable[str] | None"
    skipped_states: "Iterable[str] | None"
    failed_states: "Iterable[str] | None"
    execution_delta: "datetime.timedelta | None"
    execution_date_fn: "Callable | None"
    check_existence: "bool"
    poll_interval: "float"
    deferrable: "bool"
