# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class SlackAPIOperator(BaseOperator):
    slack_conn_id: "str"
    method: "str | None"
    api_params: "dict | None"
    base_url: "str | None"
    proxy: "str | None"
    timeout: "int | None"
    retry_handlers: "list[RetryHandler] | None"


class SlackAPIPostOperator(SlackAPIOperator):
    channel: "str"
    username: "str"
    text: "str"
    icon_url: "str"
    blocks: "list | None"
    attachments: "list | None"


class SlackAPIFileOperator(SlackAPIOperator):
    channels: "str | Sequence[str] | None"
    initial_comment: "str | None"
    filename: "str | None"
    filetype: "str | None"
    content: "str | None"
    title: "str | None"
    method_version: "Literal['v1', 'v2']"
    channel: "str | Sequence[str] | None | ArgNotSet"
