# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class MongoToS3Operator(BaseOperator):
    mongo_conn_id: "str"
    aws_conn_id: "str | None"
    mongo_collection: "str"
    mongo_query: "list | dict"
    s3_bucket: "str"
    s3_key: "str"
    mongo_db: "str | None"
    mongo_projection: "list | dict | None"
    replace: "bool"
    allow_disk_use: "bool"
    compression: "str | None"
