# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class AutoMLTrainModelOperator(GoogleCloudBaseOperator):
    model: "dict"
    location: "str"
    project_id: "str"
    metadata: "MetaData"
    timeout: "float | None"
    retry: "Retry | _MethodDefault"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class AutoMLPredictOperator(GoogleCloudBaseOperator):
    model_id: "str | None"
    endpoint_id: "str | None"
    location: "str"
    payload: "dict"
    operation_params: "dict[str, str] | None"
    instances: "list[str] | None"
    project_id: "str"
    metadata: "MetaData"
    timeout: "float | None"
    retry: "Retry | _MethodDefault"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class AutoMLBatchPredictOperator(GoogleCloudBaseOperator):
    model_id: "str"
    input_config: "dict"
    output_config: "dict"
    location: "str"
    project_id: "str"
    prediction_params: "dict[str, str] | None"
    metadata: "MetaData"
    timeout: "float | None"
    retry: "Retry | _MethodDefault"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class AutoMLCreateDatasetOperator(GoogleCloudBaseOperator):
    dataset: "dict"
    location: "str"
    project_id: "str"
    metadata: "MetaData"
    timeout: "float | None"
    retry: "Retry | _MethodDefault"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class AutoMLImportDataOperator(GoogleCloudBaseOperator):
    dataset_id: "str"
    location: "str"
    input_config: "dict"
    project_id: "str"
    metadata: "MetaData"
    timeout: "float | None"
    retry: "Retry | _MethodDefault"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class AutoMLTablesListColumnSpecsOperator(GoogleCloudBaseOperator):
    dataset_id: "str"
    table_spec_id: "str"
    location: "str"
    field_mask: "dict | None"
    filter_: "str | None"
    page_size: "int | None"
    project_id: "str"
    metadata: "MetaData"
    timeout: "float | None"
    retry: "Retry | _MethodDefault"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class AutoMLTablesUpdateDatasetOperator(GoogleCloudBaseOperator):
    dataset: "dict"
    location: "str"
    update_mask: "dict | None"
    metadata: "MetaData"
    timeout: "float | None"
    retry: "Retry | _MethodDefault"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class AutoMLGetModelOperator(GoogleCloudBaseOperator):
    model_id: "str"
    location: "str"
    project_id: "str"
    metadata: "MetaData"
    timeout: "float | None"
    retry: "Retry | _MethodDefault"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class AutoMLDeleteModelOperator(GoogleCloudBaseOperator):
    model_id: "str"
    location: "str"
    project_id: "str"
    metadata: "MetaData"
    timeout: "float | None"
    retry: "Retry | _MethodDefault"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class AutoMLDeployModelOperator(GoogleCloudBaseOperator):
    model_id: "str"
    location: "str"
    project_id: "str"
    image_detection_metadata: "dict | None"
    metadata: "Sequence[tuple[str, str]]"
    timeout: "float | None"
    retry: "Retry | _MethodDefault"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class AutoMLTablesListTableSpecsOperator(GoogleCloudBaseOperator):
    dataset_id: "str"
    location: "str"
    page_size: "int | None"
    filter_: "str | None"
    project_id: "str"
    metadata: "MetaData"
    timeout: "float | None"
    retry: "Retry | _MethodDefault"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class AutoMLListDatasetOperator(GoogleCloudBaseOperator):
    location: "str"
    project_id: "str"
    metadata: "MetaData"
    timeout: "float | None"
    retry: "Retry | _MethodDefault"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class AutoMLDeleteDatasetOperator(GoogleCloudBaseOperator):
    dataset_id: "str | list[str]"
    location: "str"
    project_id: "str"
    metadata: "MetaData"
    timeout: "float | None"
    retry: "Retry | _MethodDefault"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
