# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class CloudVideoIntelligenceDetectVideoLabelsOperator(GoogleCloudBaseOperator):
    input_uri: "str"
    input_content: "bytes | None"
    output_uri: "str | None"
    video_context: "dict | VideoContext | None"
    location: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudVideoIntelligenceDetectVideoExplicitContentOperator(GoogleCloudBaseOperator):
    input_uri: "str"
    output_uri: "str | None"
    input_content: "bytes | None"
    video_context: "dict | VideoContext | None"
    location: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudVideoIntelligenceDetectVideoShotsOperator(GoogleCloudBaseOperator):
    input_uri: "str"
    output_uri: "str | None"
    input_content: "bytes | None"
    video_context: "dict | VideoContext | None"
    location: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
