# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class DataplexTaskStateSensor(BaseSensorOperator):
    project_id: "str"
    region: "str"
    lake_id: "str"
    dataplex_task_id: "str"
    api_version: "str"
    retry: "Retry | _MethodDefault"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DataplexDataQualityJobStatusSensor(BaseSensorOperator):
    project_id: "str"
    region: "str"
    data_scan_id: "str"
    job_id: "str"
    api_version: "str"
    retry: "Retry | _MethodDefault"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    fail_on_dq_failure: "bool"
    result_timeout: "float"
    start_sensor_time: "float | None"


class DataplexDataProfileJobStatusSensor(BaseSensorOperator):
    project_id: "str"
    region: "str"
    data_scan_id: "str"
    job_id: "str"
    api_version: "str"
    retry: "Retry | _MethodDefault"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    result_timeout: "float"
    start_sensor_time: "float | None"
