# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class DatabricksReposCreateOperator(BaseOperator):
    git_url: "str"
    git_provider: "str | None"
    branch: "str | None"
    tag: "str | None"
    repo_path: "str | None"
    ignore_existing_repo: "bool"
    databricks_conn_id: "str"
    databricks_retry_limit: "int"
    databricks_retry_delay: "int"


class DatabricksReposUpdateOperator(BaseOperator):
    branch: "str | None"
    tag: "str | None"
    repo_id: "str | None"
    repo_path: "str | None"
    databricks_conn_id: "str"
    databricks_retry_limit: "int"
    databricks_retry_delay: "int"


class DatabricksReposDeleteOperator(BaseOperator):
    repo_id: "str | None"
    repo_path: "str | None"
    databricks_conn_id: "str"
    databricks_retry_limit: "int"
    databricks_retry_delay: "int"
