# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.operators.base_aws import (
    AwsBaseOperator,
)


class SqsPublishOperator(AwsBaseOperator):
    sqs_queue: "str"
    message_content: "str"
    message_attributes: "dict | None"
    delay_seconds: "int"
    message_group_id: "str | None"
