# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class LivyOperator(BaseOperator):
    file: "str"
    class_name: "str | None"
    args: "Sequence[str | int | float] | None"
    conf: "dict[Any, Any] | None"
    jars: "Sequence[str] | None"
    py_files: "Sequence[str] | None"
    files: "Sequence[str] | None"
    driver_memory: "str | None"
    driver_cores: "int | str | None"
    executor_memory: "str | None"
    executor_cores: "int | str | None"
    num_executors: "int | str | None"
    archives: "Sequence[str] | None"
    queue: "str | None"
    name: "str | None"
    proxy_user: "str | None"
    livy_conn_id: "str"
    livy_conn_auth_type: "Any | None"
    polling_interval: "int"
    extra_options: "dict[str, Any] | None"
    extra_headers: "dict[str, Any] | None"
    retry_args: "dict[str, Any] | None"
    deferrable: "bool"
