# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class AQLOperator(BaseOperator):
    query: "str"
    arangodb_conn_id: "str"
    result_processor: "Callable | None"
