# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class HdfsSensor(BaseSensorOperator):
    pass


class HdfsRegexSensor(HdfsSensor):
    pass


class HdfsFolderSensor(HdfsSensor):
    pass
