# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class CopyFromExternalStageToSnowflakeOperator(BaseOperator):
    files: "list | None"
    table: "str"
    stage: "str"
    prefix: "str | None"
    file_format: "str"
    schema: "str | None"
    columns_array: "list | None"
    pattern: "str | None"
    warehouse: "str | None"
    database: "str | None"
    autocommit: "bool"
    snowflake_conn_id: "str"
    role: "str | None"
    authenticator: "str | None"
    session_parameters: "dict | None"
    copy_options: "str | None"
    validation_mode: "str | None"
