# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class LocalFilesystemToADLSOperator(BaseOperator):
    local_path: "str"
    remote_path: "str"
    overwrite: "bool"
    nthreads: "int"
    buffersize: "int"
    blocksize: "int"
    extra_upload_options: "dict[str, Any] | None"
    azure_data_lake_conn_id: "str"
