# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.operators.base_aws import (
    AwsBaseOperator,
)


class CloudFormationCreateStackOperator(AwsBaseOperator):
    stack_name: "str"
    cloudformation_parameters: "dict"


class CloudFormationDeleteStackOperator(AwsBaseOperator):
    stack_name: "str"
    cloudformation_parameters: "dict | None"
    aws_conn_id: "str | None"
