# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class AzureFileShareToGCSOperator(BaseOperator):
    share_name: "str"
    dest_gcs: "str"
    directory_name: "str | None"
    directory_path: "str | None"
    prefix: "str"
    azure_fileshare_conn_id: "str"
    gcp_conn_id: "str"
    replace: "bool"
    gzip: "bool"
    google_impersonation_chain: "str | Sequence[str] | None"
