# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.decorators.base import DecoratedOperator
from airfly._vendor.airflow.providers.cncf.kubernetes.operators.pod import (
    KubernetesPodOperator,
)


class _KubernetesDecoratedOperator(DecoratedOperator, KubernetesPodOperator):
    namespace: "str"
    use_dill: "bool"
