# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class JenkinsBuildSensor(BaseSensorOperator):
    jenkins_connection_id: "str"
    job_name: "str"
    build_number: "int | None"
    target_states: "Iterable[str] | None"
