# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.sensors.base_aws import AwsBaseSensor


class GlueCatalogPartitionSensor(AwsBaseSensor):
    table_name: "str"
    expression: "str"
    database_name: "str"
    poke_interval: "int"
    deferrable: "bool"
