# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class JiraSensor(BaseSensorOperator):
    method_name: "str"
    jira_conn_id: "str"
    method_params: "dict | None"
    result_processor: "Callable | None"


class JiraTicketSensor(JiraSensor):
    jira_conn_id: "str"
    ticket_id: "str | None"
    field: "str | None"
    expected_value: "str | None"
    field_checker_func: "Callable | None"
