# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class BigQueryToBigQueryOperator(BaseOperator):
    source_project_dataset_tables: "list[str] | str"
    destination_project_dataset_table: "str"
    write_disposition: "str"
    create_disposition: "str"
    gcp_conn_id: "str"
    labels: "dict | None"
    encryption_configuration: "dict | None"
    location: "str | None"
    impersonation_chain: "str | Sequence[str] | None"
