# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class GCSToSFTPOperator(BaseOperator):
    source_bucket: "str"
    source_object: "str"
    destination_path: "str"
    keep_directory_structure: "bool"
    move_object: "bool"
    gcp_conn_id: "str"
    sftp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
