# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.operators.branch import BaseBranchOperator


class BranchDayOfWeekOperator(BaseBranchOperator):
    follow_task_ids_if_true: "str | Iterable[str]"
    follow_task_ids_if_false: "str | Iterable[str]"
    week_day: "str | Iterable[str] | WeekDay | Iterable[WeekDay]"
    use_task_logical_date: "bool"
    use_task_execution_day: "bool"
