# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class CloudDataFusionRestartInstanceOperator(GoogleCloudBaseOperator):
    instance_name: "str"
    location: "str"
    project_id: "str"
    api_version: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataFusionDeleteInstanceOperator(GoogleCloudBaseOperator):
    instance_name: "str"
    location: "str"
    project_id: "str"
    api_version: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataFusionCreateInstanceOperator(GoogleCloudBaseOperator):
    instance_name: "str"
    instance: "dict[str, Any]"
    location: "str"
    project_id: "str"
    api_version: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataFusionUpdateInstanceOperator(GoogleCloudBaseOperator):
    instance_name: "str"
    instance: "dict[str, Any]"
    update_mask: "str"
    location: "str"
    project_id: "str"
    api_version: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataFusionGetInstanceOperator(GoogleCloudBaseOperator):
    instance_name: "str"
    location: "str"
    project_id: "str"
    api_version: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataFusionCreatePipelineOperator(GoogleCloudBaseOperator):
    pipeline_name: "str"
    pipeline: "dict[str, Any]"
    instance_name: "str"
    location: "str"
    namespace: "str"
    project_id: "str"
    api_version: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataFusionDeletePipelineOperator(GoogleCloudBaseOperator):
    pipeline_name: "str"
    instance_name: "str"
    location: "str"
    version_id: "str | None"
    namespace: "str"
    project_id: "str"
    api_version: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataFusionListPipelinesOperator(GoogleCloudBaseOperator):
    instance_name: "str"
    location: "str"
    artifact_name: "str | None"
    artifact_version: "str | None"
    namespace: "str"
    project_id: "str"
    api_version: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataFusionStartPipelineOperator(GoogleCloudBaseOperator):
    pipeline_name: "str"
    instance_name: "str"
    location: "str"
    pipeline_type: "DataFusionPipelineType"
    runtime_args: "dict[str, Any] | None"
    success_states: "list[str] | None"
    namespace: "str"
    pipeline_timeout: "int"
    project_id: "str"
    api_version: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    asynchronous: "_empty"
    deferrable: "bool"
    poll_interval: "_empty"


class CloudDataFusionStopPipelineOperator(GoogleCloudBaseOperator):
    pipeline_name: "str"
    instance_name: "str"
    location: "str"
    namespace: "str"
    project_id: "str"
    api_version: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
