# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class OpsgenieCreateAlertOperator(BaseOperator):
    message: "str"
    opsgenie_conn_id: "str"
    alias: "str | None"
    description: "str | None"
    responders: "list[dict] | None"
    visible_to: "list[dict] | None"
    actions: "list[str] | None"
    tags: "list[str] | None"
    details: "dict | None"
    entity: "str | None"
    source: "str | None"
    priority: "str | None"
    user: "str | None"
    note: "str | None"


class OpsgenieCloseAlertOperator(BaseOperator):
    identifier: "str"
    opsgenie_conn_id: "str"
    identifier_type: "str | None"
    user: "str | None"
    note: "str | None"
    source: "str | None"
    close_alert_kwargs: "dict | None"


class OpsgenieDeleteAlertOperator(BaseOperator):
    identifier: "str"
    opsgenie_conn_id: "str"
    identifier_type: "str | None"
    user: "str | None"
    source: "str | None"
