# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class SalesforceBulkOperator(BaseOperator):
    operation: "Literal['insert', 'update', 'upsert', 'delete', 'hard_delete']"
    object_name: "str"
    payload: "list"
    external_id_field: "str"
    batch_size: "int"
    use_serial: "bool"
    salesforce_conn_id: "str"
