# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class AzureBatchOperator(BaseOperator):
    batch_pool_id: "str"
    batch_pool_vm_size: "str"
    batch_job_id: "str"
    batch_task_command_line: "str"
    batch_task_id: "str"
    vm_node_agent_sku_id: "str"
    vm_publisher: "str | None"
    vm_offer: "str | None"
    sku_starts_with: "str | None"
    vm_sku: "str | None"
    vm_version: "str | None"
    os_family: "str | None"
    os_version: "str | None"
    batch_pool_display_name: "str | None"
    batch_job_display_name: "str | None"
    batch_job_manager_task: "batch_models.JobManagerTask | None"
    batch_job_preparation_task: "batch_models.JobPreparationTask | None"
    batch_job_release_task: "batch_models.JobReleaseTask | None"
    batch_task_display_name: "str | None"
    batch_task_container_settings: "batch_models.TaskContainerSettings | None"
    batch_start_task: "batch_models.StartTask | None"
    batch_max_retries: "int"
    batch_task_resource_files: "list[batch_models.ResourceFile] | None"
    batch_task_output_files: "list[batch_models.OutputFile] | None"
    batch_task_user_identity: "batch_models.UserIdentity | None"
    target_low_priority_nodes: "int | None"
    target_dedicated_nodes: "int | None"
    enable_auto_scale: "bool"
    auto_scale_formula: "str | None"
    azure_batch_conn_id: "_empty"
    use_latest_verified_vm_image_and_sku: "bool"
    timeout: "int"
    should_delete_job: "bool"
    should_delete_pool: "bool"
