# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class EC2InstanceStateSensor(BaseSensorOperator):
    target_state: "str"
    instance_id: "str"
    aws_conn_id: "str | None"
    region_name: "str | None"
    deferrable: "bool"
