# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class S3ToSqlOperator(BaseOperator):
    s3_key: "str"
    s3_bucket: "str"
    table: "str"
    parser: "Callable[[str], Iterable[Iterable]]"
    column_list: "list[str] | None"
    commit_every: "int"
    schema: "str | None"
    sql_conn_id: "str"
    sql_hook_params: "dict | None"
    aws_conn_id: "str | None"
