# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class HttpToS3Operator(BaseOperator):
    endpoint: "str | None"
    method: "str"
    data: "Any"
    headers: "dict[str, str] | None"
    extra_options: "dict[str, Any] | None"
    http_conn_id: "str"
    log_response: "bool"
    auth_type: "type[AuthBase] | None"
    tcp_keep_alive: "bool"
    tcp_keep_alive_idle: "int"
    tcp_keep_alive_count: "int"
    tcp_keep_alive_interval: "int"
    s3_bucket: "str | None"
    s3_key: "str"
    replace: "bool"
    encrypt: "bool"
    acl_policy: "str | None"
    aws_conn_id: "str | None"
    verify: "str | bool | None"
