# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.operators.base_aws import (
    AwsBaseOperator,
)


class KinesisAnalyticsV2CreateApplicationOperator(AwsBaseOperator):
    application_name: "str"
    runtime_environment: "str"
    service_execution_role: "str"
    create_application_kwargs: "dict[str, Any] | None"
    application_description: "str"


class KinesisAnalyticsV2StartApplicationOperator(AwsBaseOperator):
    application_name: "str"
    run_configuration: "dict[str, Any] | None"
    wait_for_completion: "bool"
    waiter_delay: "int"
    waiter_max_attempts: "int"
    deferrable: "bool"


class KinesisAnalyticsV2StopApplicationOperator(AwsBaseOperator):
    application_name: "str"
    force: "bool"
    wait_for_completion: "bool"
    waiter_delay: "int"
    waiter_max_attempts: "int"
    deferrable: "bool"
