# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class CloudTranslateSpeechOperator(GoogleCloudBaseOperator):
    audio: "RecognitionAudio"
    config: "RecognitionConfig"
    target_language: "str"
    format_: "str"
    source_language: "str | None"
    model: "str"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
