# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class CassandraToGCSOperator(BaseOperator):
    cql: "str"
    bucket: "str"
    filename: "str"
    schema_filename: "str | None"
    approx_max_file_size_bytes: "int"
    gzip: "bool"
    cassandra_conn_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    query_timeout: "float | None | NotSetType"
    encode_uuid: "bool"
