# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.sensors.base_aws import AwsBaseSensor


class KinesisAnalyticsV2BaseSensor(AwsBaseSensor):
    application_name: "str"
    deferrable: "bool"


class KinesisAnalyticsV2StartApplicationCompletedSensor(KinesisAnalyticsV2BaseSensor):
    application_name: "str"
    max_retries: "int"
    poke_interval: "int"


class KinesisAnalyticsV2StopApplicationCompletedSensor(KinesisAnalyticsV2BaseSensor):
    application_name: "str"
    max_retries: "int"
    poke_interval: "int"
