# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.sensors.base_aws import AwsBaseSensor


class LambdaFunctionStateSensor(AwsBaseSensor):
    function_name: "str"
    qualifier: "str | None"
    target_states: "list | None"
