# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class CloudComposerCreateEnvironmentOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    environment_id: "str"
    environment: "Environment | dict"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    deferrable: "bool"
    pooling_period_seconds: "int"


class CloudComposerDeleteEnvironmentOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    environment_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    deferrable: "bool"
    pooling_period_seconds: "int"


class CloudComposerGetEnvironmentOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    environment_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudComposerListEnvironmentsOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    page_size: "int | None"
    page_token: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudComposerUpdateEnvironmentOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    environment_id: "str"
    environment: "dict | Environment"
    update_mask: "dict | FieldMask"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    deferrable: "bool"
    pooling_period_seconds: "int"


class CloudComposerListImageVersionsOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    page_size: "int | None"
    page_token: "str | None"
    include_past_releases: "bool"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudComposerRunAirflowCLICommandOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    environment_id: "str"
    command: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    deferrable: "bool"
    poll_interval: "int"
