# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.operators.base_aws import (
    AwsBaseOperator,
)


class DmsCreateTaskOperator(AwsBaseOperator):
    replication_task_id: "str"
    source_endpoint_arn: "str"
    target_endpoint_arn: "str"
    replication_instance_arn: "str"
    table_mappings: "dict"
    migration_type: "str"
    create_task_kwargs: "dict | None"
    aws_conn_id: "str | None"


class DmsDeleteTaskOperator(AwsBaseOperator):
    replication_task_arn: "str | None"


class DmsDescribeTasksOperator(AwsBaseOperator):
    describe_tasks_kwargs: "dict | None"


class DmsStartTaskOperator(AwsBaseOperator):
    replication_task_arn: "str"
    start_replication_task_type: "str"
    start_task_kwargs: "dict | None"
    aws_conn_id: "str | None"


class DmsStopTaskOperator(AwsBaseOperator):
    replication_task_arn: "str | None"
