# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class CloudTextToSpeechSynthesizeOperator(GoogleCloudBaseOperator):
    input_data: "dict | SynthesisInput"
    voice: "dict | VoiceSelectionParams"
    audio_config: "dict | AudioConfig"
    target_bucket_name: "str"
    target_filename: "str"
    project_id: "str"
    gcp_conn_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    impersonation_chain: "str | Sequence[str] | None"
