# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class DbtCloudJobRunSensor(BaseSensorOperator):
    dbt_cloud_conn_id: "str"
    run_id: "int"
    account_id: "int | None"
    deferrable: "bool"


class DbtCloudJobRunAsyncSensor(DbtCloudJobRunSensor):
    pass
