# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class BatchOperator(BaseOperator):
    job_name: "str"
    job_definition: "str"
    job_queue: "str"
    overrides: "dict | None"
    container_overrides: "dict | None"
    array_properties: "dict | None"
    ecs_properties_override: "dict | None"
    node_overrides: "dict | None"
    share_identifier: "str | None"
    scheduling_priority_override: "int | None"
    parameters: "dict | None"
    retry_strategy: "dict | None"
    job_id: "str | None"
    waiters: "Any | None"
    max_retries: "int"
    status_retries: "int | None"
    aws_conn_id: "str | None"
    region_name: "str | None"
    tags: "dict | None"
    wait_for_completion: "bool"
    deferrable: "bool"
    poll_interval: "int"
    awslogs_enabled: "bool"
    awslogs_fetch_interval: "timedelta"


class BatchCreateComputeEnvironmentOperator(BaseOperator):
    compute_environment_name: "str"
    environment_type: "str"
    state: "str"
    compute_resources: "dict"
    unmanaged_v_cpus: "int | None"
    service_role: "str | None"
    tags: "dict | None"
    poll_interval: "int"
    max_retries: "int | None"
    aws_conn_id: "str | None"
    region_name: "str | None"
    deferrable: "bool"
    status_retries: "_empty"
