# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class TableauOperator(BaseOperator):
    resource: "str"
    method: "str"
    find: "str"
    match_with: "str"
    site_id: "str | None"
    blocking_refresh: "bool"
    check_interval: "float"
    tableau_conn_id: "str"
