# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.sensors.base_aws import AwsBaseSensor


class SqsSensor(AwsBaseSensor):
    sqs_queue: "_empty"
    max_messages: "int"
    num_batches: "int"
    wait_time_seconds: "int"
    visibility_timeout: "int | None"
    message_filtering: "MessageFilteringType | None"
    message_filtering_match_values: "Any"
    message_filtering_config: "Any"
    delete_message_on_reception: "bool"
    deferrable: "bool"
