# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.bigtable import (
    BigtableValidationMixin,
)
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class BigtableTableReplicationCompletedSensor(
    BaseSensorOperator, BigtableValidationMixin
):
    instance_id: "str"
    table_id: "str"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
