# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class CloudSQLBaseOperator(GoogleCloudBaseOperator):
    instance: "str"
    project_id: "str"
    gcp_conn_id: "str"
    api_version: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudSQLCreateInstanceOperator(CloudSQLBaseOperator):
    body: "dict"
    instance: "str"
    project_id: "str"
    gcp_conn_id: "str"
    api_version: "str"
    validate_body: "bool"
    impersonation_chain: "str | Sequence[str] | None"


class CloudSQLInstancePatchOperator(CloudSQLBaseOperator):
    body: "dict"
    instance: "str"
    project_id: "str"
    gcp_conn_id: "str"
    api_version: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudSQLDeleteInstanceOperator(CloudSQLBaseOperator):
    instance: "str"
    project_id: "str"
    gcp_conn_id: "str"
    api_version: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudSQLCloneInstanceOperator(CloudSQLBaseOperator):
    instance: "str"
    destination_instance_name: "str"
    clone_context: "dict | None"
    project_id: "str"
    gcp_conn_id: "str"
    api_version: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudSQLCreateInstanceDatabaseOperator(CloudSQLBaseOperator):
    instance: "str"
    body: "dict"
    project_id: "str"
    gcp_conn_id: "str"
    api_version: "str"
    validate_body: "bool"
    impersonation_chain: "str | Sequence[str] | None"


class CloudSQLPatchInstanceDatabaseOperator(CloudSQLBaseOperator):
    instance: "str"
    database: "str"
    body: "dict"
    project_id: "str"
    gcp_conn_id: "str"
    api_version: "str"
    validate_body: "bool"
    impersonation_chain: "str | Sequence[str] | None"


class CloudSQLDeleteInstanceDatabaseOperator(CloudSQLBaseOperator):
    instance: "str"
    database: "str"
    project_id: "str"
    gcp_conn_id: "str"
    api_version: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudSQLExportInstanceOperator(CloudSQLBaseOperator):
    instance: "str"
    body: "dict"
    project_id: "str"
    gcp_conn_id: "str"
    api_version: "str"
    validate_body: "bool"
    impersonation_chain: "str | Sequence[str] | None"
    deferrable: "bool"
    poke_interval: "int"


class CloudSQLImportInstanceOperator(CloudSQLBaseOperator):
    instance: "str"
    body: "dict"
    project_id: "str"
    gcp_conn_id: "str"
    api_version: "str"
    validate_body: "bool"
    impersonation_chain: "str | Sequence[str] | None"


class CloudSQLExecuteQueryOperator(GoogleCloudBaseOperator):
    sql: "str | Iterable[str]"
    autocommit: "bool"
    parameters: "Iterable | Mapping[str, Any] | None"
    gcp_conn_id: "str"
    gcp_cloudsql_conn_id: "str"
    sql_proxy_binary_path: "str | None"
    ssl_server_cert: "str | None"
    ssl_client_cert: "str | None"
    ssl_client_key: "str | None"
    ssl_secret_id: "str | None"
