# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.sensors.base_aws import AwsBaseSensor


class QuickSightSensor(AwsBaseSensor):
    data_set_id: "str"
    ingestion_id: "str"
