# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class HiveStatsCollectionOperator(BaseOperator):
    table: "str"
    partition: "Any"
    extra_exprs: "dict[str, Any] | None"
    excluded_columns: "list[str] | None"
    assignment_func: "Callable[[str, str], dict[Any, Any] | None] | None"
    metastore_conn_id: "str"
    presto_conn_id: "str"
    mysql_conn_id: "str"
    ds: "str"
    dttm: "str"
