# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class CreateEndpointOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    endpoint: "Endpoint | dict"
    endpoint_id: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DeleteEndpointOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    endpoint_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DeployModelOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    endpoint_id: "str"
    deployed_model: "DeployedModel | dict"
    traffic_split: "Sequence | dict | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class GetEndpointOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    endpoint_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class ListEndpointsOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    filter: "str | None"
    page_size: "int | None"
    page_token: "str | None"
    read_mask: "str | None"
    order_by: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class UndeployModelOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    endpoint_id: "str"
    deployed_model_id: "str"
    traffic_split: "Sequence | dict | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class UpdateEndpointOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    endpoint_id: "str"
    endpoint: "Endpoint | dict"
    update_mask: "FieldMask | dict"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
