# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class EksBaseSensor(BaseSensorOperator):
    cluster_name: "str"
    target_state: "ClusterStates | NodegroupStates | FargateProfileStates"
    target_state_type: "type"
    aws_conn_id: "str | None"
    region: "str | None"


class EksClusterStateSensor(EksBaseSensor):
    target_state: "ClusterStates"


class EksFargateProfileStateSensor(EksBaseSensor):
    fargate_profile_name: "str"
    target_state: "FargateProfileStates"


class EksNodegroupStateSensor(EksBaseSensor):
    nodegroup_name: "str"
    target_state: "NodegroupStates"
