# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class SubDagOperator(BaseSensorOperator):
    subdag: "DAG"
    session: "Session"
    conf: "dict | None"
    propagate_skipped_state: "SkippedStatePropagationOptions | None"
