# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class PythonSensor(BaseSensorOperator):
    python_callable: "Callable"
    op_args: "list | None"
    op_kwargs: "Mapping[str, Any] | None"
    templates_dict: "dict | None"
