# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class MySqlToHiveOperator(BaseOperator):
    sql: "str"
    hive_table: "str"
    create: "bool"
    recreate: "bool"
    partition: "dict | None"
    delimiter: "str"
    quoting: "int | None"
    quotechar: "str"
    escapechar: "str | None"
    mysql_conn_id: "str"
    hive_cli_conn_id: "str"
    hive_auth: "str | None"
    tblproperties: "dict | None"
