# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class AzureBlobStorageToTeradataOperator(BaseOperator):
    blob_source_key: "str"
    public_bucket: "bool"
    azure_conn_id: "str"
    teradata_table: "str"
    teradata_conn_id: "str"
    teradata_authorization_name: "str"
