# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class WorkflowExecutionSensor(BaseSensorOperator):
    workflow_id: "str"
    execution_id: "str"
    location: "str"
    project_id: "str"
    success_states: "set[Execution.State] | None"
    failure_states: "set[Execution.State] | None"
    retry: "Retry | _MethodDefault"
    request_timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
