# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.taskmixin import DAGNode
from airfly._vendor.airflow.template.templater import Templater


class AbstractOperator(Templater, DAGNode):
    context: "_empty"
