# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class LivySensor(BaseSensorOperator):
    batch_id: "int | str"
    livy_conn_id: "str"
    livy_conn_auth_type: "Any | None"
    extra_options: "dict[str, Any] | None"
