# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class SingularityOperator(BaseOperator):
    image: "str"
    command: "str | ast.AST"
    start_command: "str | list[str] | None"
    environment: "dict[str, Any] | None"
    pull_folder: "str | None"
    working_dir: "str | None"
    force_pull: "bool | None"
    volumes: "list[str] | None"
    options: "list[str] | None"
    auto_remove: "bool | None"
