# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator
from airfly._vendor.airflow.providers.cncf.kubernetes.operators.pod import (
    KubernetesPodOperator,
)


class EksCreateClusterOperator(BaseOperator):
    cluster_name: "str"
    cluster_role_arn: "str"
    resources_vpc_config: "dict"
    compute: "str | None"
    create_cluster_kwargs: "dict | None"
    nodegroup_name: "str"
    nodegroup_role_arn: "str | None"
    create_nodegroup_kwargs: "dict | None"
    fargate_profile_name: "str"
    fargate_pod_execution_role_arn: "str | None"
    fargate_selectors: "list | None"
    create_fargate_profile_kwargs: "dict | None"
    wait_for_completion: "bool"
    aws_conn_id: "str | None"
    region: "str | None"
    deferrable: "bool"
    waiter_delay: "int"
    waiter_max_attempts: "int"


class EksCreateNodegroupOperator(BaseOperator):
    cluster_name: "str"
    nodegroup_subnets: "list[str] | str"
    nodegroup_role_arn: "str"
    nodegroup_name: "str"
    create_nodegroup_kwargs: "dict | None"
    wait_for_completion: "bool"
    aws_conn_id: "str | None"
    region: "str | None"
    waiter_delay: "int"
    waiter_max_attempts: "int"
    deferrable: "bool"


class EksCreateFargateProfileOperator(BaseOperator):
    cluster_name: "str"
    pod_execution_role_arn: "str"
    selectors: "list"
    fargate_profile_name: "str"
    create_fargate_profile_kwargs: "dict | None"
    wait_for_completion: "bool"
    aws_conn_id: "str | None"
    region: "str | None"
    waiter_delay: "int"
    waiter_max_attempts: "int"
    deferrable: "bool"


class EksDeleteClusterOperator(BaseOperator):
    cluster_name: "str"
    force_delete_compute: "bool"
    wait_for_completion: "bool"
    aws_conn_id: "str | None"
    region: "str | None"
    deferrable: "bool"
    waiter_delay: "int"
    waiter_max_attempts: "int"


class EksDeleteNodegroupOperator(BaseOperator):
    cluster_name: "str"
    nodegroup_name: "str"
    wait_for_completion: "bool"
    aws_conn_id: "str | None"
    region: "str | None"
    waiter_delay: "int"
    waiter_max_attempts: "int"
    deferrable: "bool"


class EksDeleteFargateProfileOperator(BaseOperator):
    cluster_name: "str"
    fargate_profile_name: "str"
    wait_for_completion: "bool"
    aws_conn_id: "str | None"
    region: "str | None"
    waiter_delay: "int"
    waiter_max_attempts: "int"
    deferrable: "bool"


class EksPodOperator(KubernetesPodOperator):
    cluster_name: "str"
    in_cluster: "bool"
    namespace: "str"
    pod_context: "str | None"
    pod_name: "str | None"
    pod_username: "str | None"
    aws_conn_id: "str | None"
    region: "str | None"
    on_finish_action: "str | None"
    is_delete_operator_pod: "bool | None"
