# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class ConsumeFromTopicOperator(BaseOperator):
    topics: "str | Sequence[str]"
    kafka_config_id: "str"
    apply_function: "Callable[..., Any] | str | None"
    apply_function_batch: "Callable[..., Any] | str | None"
    apply_function_args: "Sequence[Any] | None"
    apply_function_kwargs: "dict[Any, Any] | None"
    commit_cadence: "str | None"
    max_messages: "int | None"
    max_batch_size: "int"
    poll_timeout: "float"
