# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class BaseSQLToGCSOperator(BaseOperator):
    sql: "str"
    bucket: "str"
    filename: "str"
    schema_filename: "str | None"
    approx_max_file_size_bytes: "int"
    export_format: "str"
    stringify_dict: "bool"
    field_delimiter: "str"
    null_marker: "str | None"
    gzip: "bool"
    schema: "str | list | None"
    parameters: "dict | None"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    upload_metadata: "bool"
    exclude_columns: "set | None"
    partition_columns: "list | None"
    write_on_empty: "bool"
    parquet_row_group_size: "int"
