# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.decorators.base import DecoratedOperator
from airfly._vendor.airflow.operators.python import PythonOperator


class _PySparkDecoratedOperator(DecoratedOperator, PythonOperator):
    python_callable: "Callable"
    op_args: "Sequence | None"
    op_kwargs: "dict | None"
    conn_id: "str | None"
    config_kwargs: "dict | None"
