# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class DataprepJobGroupIsFinishedSensor(BaseSensorOperator):
    job_group_id: "int | str"
    dataprep_conn_id: "str"
