# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class AutoMLTrainingJobBaseOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    display_name: "str"
    labels: "dict[str, str] | None"
    parent_model: "str | None"
    is_default_version: "bool | None"
    model_version_aliases: "list[str] | None"
    model_version_description: "str | None"
    training_encryption_spec_key_name: "str | None"
    model_encryption_spec_key_name: "str | None"
    training_fraction_split: "float | None"
    test_fraction_split: "float | None"
    model_display_name: "str | None"
    model_labels: "dict[str, str] | None"
    sync: "bool"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CreateAutoMLForecastingTrainingJobOperator(AutoMLTrainingJobBaseOperator):
    dataset_id: "str"
    target_column: "str"
    time_column: "str"
    time_series_identifier_column: "str"
    unavailable_at_forecast_columns: "list[str]"
    available_at_forecast_columns: "list[str]"
    forecast_horizon: "int"
    data_granularity_unit: "str"
    data_granularity_count: "int"
    optimization_objective: "str | None"
    column_specs: "dict[str, str] | None"
    column_transformations: "list[dict[str, dict[str, str]]] | None"
    validation_fraction_split: "float | None"
    predefined_split_column_name: "str | None"
    weight_column: "str | None"
    time_series_attribute_columns: "list[str] | None"
    context_window: "int | None"
    export_evaluated_data_items: "bool"
    export_evaluated_data_items_bigquery_destination_uri: "str | None"
    export_evaluated_data_items_override_destination: "bool"
    quantiles: "list[float] | None"
    validation_options: "str | None"
    budget_milli_node_hours: "int"
    region: "str"
    impersonation_chain: "str | Sequence[str] | None"
    parent_model: "str | None"
    window_stride_length: "int | None"
    window_max_count: "int | None"


class CreateAutoMLImageTrainingJobOperator(AutoMLTrainingJobBaseOperator):
    dataset_id: "str"
    prediction_type: "str"
    multi_label: "bool"
    model_type: "str"
    base_model: "Model | None"
    validation_fraction_split: "float | None"
    training_filter_split: "str | None"
    validation_filter_split: "str | None"
    test_filter_split: "str | None"
    budget_milli_node_hours: "int | None"
    disable_early_stopping: "bool"
    region: "str"
    impersonation_chain: "str | Sequence[str] | None"
    parent_model: "str | None"


class CreateAutoMLTabularTrainingJobOperator(AutoMLTrainingJobBaseOperator):
    dataset_id: "str"
    target_column: "str"
    optimization_prediction_type: "str"
    optimization_objective: "str | None"
    column_specs: "dict[str, str] | None"
    column_transformations: "list[dict[str, dict[str, str]]] | None"
    optimization_objective_recall_value: "float | None"
    optimization_objective_precision_value: "float | None"
    validation_fraction_split: "float | None"
    predefined_split_column_name: "str | None"
    timestamp_split_column_name: "str | None"
    weight_column: "str | None"
    budget_milli_node_hours: "int"
    disable_early_stopping: "bool"
    export_evaluated_data_items: "bool"
    export_evaluated_data_items_bigquery_destination_uri: "str | None"
    export_evaluated_data_items_override_destination: "bool"
    region: "str"
    impersonation_chain: "str | Sequence[str] | None"
    parent_model: "str | None"


class CreateAutoMLTextTrainingJobOperator(AutoMLTrainingJobBaseOperator):
    dataset_id: "str"
    prediction_type: "str"
    multi_label: "bool"
    sentiment_max: "int"
    validation_fraction_split: "float | None"
    training_filter_split: "str | None"
    validation_filter_split: "str | None"
    test_filter_split: "str | None"


class CreateAutoMLVideoTrainingJobOperator(AutoMLTrainingJobBaseOperator):
    dataset_id: "str"
    prediction_type: "str"
    model_type: "str"
    training_filter_split: "str | None"
    test_filter_split: "str | None"
    region: "str"
    impersonation_chain: "str | Sequence[str] | None"
    parent_model: "str | None"


class DeleteAutoMLTrainingJobOperator(GoogleCloudBaseOperator):
    training_pipeline_id: "str"
    region: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class ListAutoMLTrainingJobOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    page_size: "int | None"
    page_token: "str | None"
    filter: "str | None"
    read_mask: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
