# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class FileSensor(BaseSensorOperator):
    filepath: "_empty"
    fs_conn_id: "_empty"
    recursive: "_empty"
    deferrable: "bool"
    start_from_trigger: "bool"
    trigger_kwargs: "dict[str, Any] | None"
