# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class WinRMOperator(BaseOperator):
    winrm_hook: "WinRMHook | None"
    ssh_conn_id: "str | None"
    remote_host: "str | None"
    command: "str | None"
    ps_path: "str | None"
    output_encoding: "str"
    timeout: "int"
