# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class BigQueryToGCSOperator(BaseOperator):
    source_project_dataset_table: "str"
    destination_cloud_storage_uris: "list[str]"
    project_id: "str"
    compression: "str"
    export_format: "str"
    field_delimiter: "str"
    print_header: "bool"
    gcp_conn_id: "str"
    labels: "dict | None"
    location: "str | None"
    impersonation_chain: "str | Sequence[str] | None"
    result_retry: "Retry"
    result_timeout: "float | None"
    job_id: "str | None"
    force_rerun: "bool"
    reattach_states: "set[str] | None"
    deferrable: "bool"
