# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class AzureDataFactoryPipelineRunStatusSensor(BaseSensorOperator):
    run_id: "str"
    azure_data_factory_conn_id: "str"
    resource_group_name: "str"
    factory_name: "str"
    deferrable: "bool"
