# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class FTPToS3Operator(BaseOperator):
    ftp_path: "str"
    s3_bucket: "str"
    s3_key: "str"
    ftp_filenames: "str | list[str] | None"
    s3_filenames: "str | list[str] | None"
    ftp_conn_id: "str"
    aws_conn_id: "str | None"
    replace: "bool"
    encrypt: "bool"
    gzip: "bool"
    acl_policy: "str | None"
