# Auto generated by 'inv collect-airflow'
from airfly._vendor.abc import ABC
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class BeamDataflowMixin:
    pass


class BeamBasePipelineOperator(BaseOperator, BeamDataflowMixin, ABC):
    runner: "str"
    default_pipeline_options: "dict | None"
    pipeline_options: "dict | None"
    gcp_conn_id: "str"
    dataflow_config: "DataflowConfiguration | dict | None"


class BeamRunPythonPipelineOperator(BeamBasePipelineOperator):
    py_file: "str"
    runner: "str"
    default_pipeline_options: "dict | None"
    pipeline_options: "dict | None"
    py_interpreter: "str"
    py_options: "list[str] | None"
    py_requirements: "list[str] | None"
    py_system_site_packages: "bool"
    gcp_conn_id: "str"
    dataflow_config: "DataflowConfiguration | dict | None"
    deferrable: "bool"


class BeamRunJavaPipelineOperator(BeamBasePipelineOperator):
    jar: "str"
    runner: "str"
    job_class: "str | None"
    default_pipeline_options: "dict | None"
    pipeline_options: "dict | None"
    gcp_conn_id: "str"
    dataflow_config: "DataflowConfiguration | dict | None"
    deferrable: "bool"


class BeamRunGoPipelineOperator(BeamBasePipelineOperator):
    go_file: "str"
    launcher_binary: "str"
    worker_binary: "str"
    runner: "str"
    default_pipeline_options: "dict | None"
    pipeline_options: "dict | None"
    gcp_conn_id: "str"
    dataflow_config: "DataflowConfiguration | dict | None"
