# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class HttpOperator(BaseOperator):
    endpoint: "str | None"
    method: "str"
    data: "dict[str, Any] | str | None"
    headers: "dict[str, str] | None"
    pagination_function: "Callable[..., Any] | None"
    response_check: "Callable[..., bool] | None"
    response_filter: "Callable[..., Any] | None"
    extra_options: "dict[str, Any] | None"
    http_conn_id: "str"
    log_response: "bool"
    auth_type: "type[AuthBase] | None"
    tcp_keep_alive: "bool"
    tcp_keep_alive_idle: "int"
    tcp_keep_alive_count: "int"
    tcp_keep_alive_interval: "int"
    deferrable: "bool"
    retry_args: "dict[str, Any] | None"


class SimpleHttpOperator(HttpOperator):
    pass
