# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.transfers.sql_to_gcs import (
    BaseSQLToGCSOperator,
)


class PostgresToGCSOperator(BaseSQLToGCSOperator):
    postgres_conn_id: "_empty"
    use_server_side_cursor: "_empty"
    cursor_itersize: "_empty"
