# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class YQExecuteQueryOperator(BaseOperator):
    name: "str | None"
    folder_id: "str | None"
    yandex_conn_id: "str | None"
    public_ssh_key: "str | None"
    service_account_id: "str | None"
    sql: "str"
