# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class HiveToDynamoDBOperator(BaseOperator):
    sql: "str"
    table_name: "str"
    table_keys: "list"
    pre_process: "Callable | None"
    pre_process_args: "list | None"
    pre_process_kwargs: "list | None"
    region_name: "str | None"
    schema: "str"
    hiveserver2_conn_id: "str"
    aws_conn_id: "str | None"
