# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class WasbBlobSensor(BaseSensorOperator):
    container_name: "str"
    blob_name: "str"
    wasb_conn_id: "str"
    check_options: "dict | None"
    public_read: "bool"
    deferrable: "bool"


class WasbBlobAsyncSensor(WasbBlobSensor):
    pass


class WasbPrefixSensor(BaseSensorOperator):
    container_name: "str"
    prefix: "str"
    wasb_conn_id: "str"
    check_options: "dict | None"
    public_read: "bool"
    deferrable: "bool"
