# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class MSGraphSensor(BaseSensorOperator):
    url: "str"
    response_type: "ResponseType | None"
    path_parameters: "dict[str, Any] | None"
    url_template: "str | None"
    method: "str"
    query_parameters: "dict[str, QueryParams] | None"
    headers: "dict[str, str] | None"
    data: "dict[str, Any] | str | BytesIO | None"
    conn_id: "str"
    proxies: "dict | None"
    api_version: "APIVersion | None"
    event_processor: "Callable[[Context, Any], bool]"
    result_processor: "Callable[[Context, Any], Any]"
    serializer: "type[ResponseSerializer]"
    retry_delay: "timedelta | float"
