# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class CreateHyperparameterTuningJobOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    display_name: "str"
    metric_spec: "dict[str, str]"
    parameter_spec: "dict[str, hyperparameter_tuning._ParameterSpec]"
    max_trial_count: "int"
    parallel_trial_count: "int"
    worker_pool_specs: "list[dict] | list[gapic.WorkerPoolSpec]"
    base_output_dir: "str | None"
    custom_job_labels: "dict[str, str] | None"
    custom_job_encryption_spec_key_name: "str | None"
    staging_bucket: "str | None"
    max_failed_trial_count: "int"
    search_algorithm: "str | None"
    measurement_selection: "str | None"
    hyperparameter_tuning_job_labels: "dict[str, str] | None"
    hyperparameter_tuning_job_encryption_spec_key_name: "str | None"
    service_account: "str | None"
    network: "str | None"
    timeout: "int | None"
    restart_job_on_worker_restart: "bool"
    enable_web_access: "bool"
    tensorboard: "str | None"
    sync: "bool"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    deferrable: "bool"
    poll_interval: "int"


class GetHyperparameterTuningJobOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    hyperparameter_tuning_job_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DeleteHyperparameterTuningJobOperator(GoogleCloudBaseOperator):
    hyperparameter_tuning_job_id: "str"
    region: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class ListHyperparameterTuningJobOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    page_size: "int | None"
    page_token: "str | None"
    filter: "str | None"
    read_mask: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
