# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class CreateDatasetOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    dataset: "Dataset | dict"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class GetDatasetOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    dataset_id: "str"
    read_mask: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DeleteDatasetOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    dataset_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class ExportDataOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    dataset_id: "str"
    export_config: "ExportDataConfig | dict"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class ImportDataOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    dataset_id: "str"
    import_configs: "Sequence[ImportDataConfig] | list"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class ListDatasetsOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    filter: "str | None"
    page_size: "int | None"
    page_token: "str | None"
    read_mask: "str | None"
    order_by: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class UpdateDatasetOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    dataset_id: "str"
    dataset: "Dataset | dict"
    update_mask: "FieldMask | dict"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
