# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class RedisPublishOperator(BaseOperator):
    channel: "str"
    message: "str"
    redis_conn_id: "str"
