# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class FileTransferOperator(BaseOperator):
    src: "str | ObjectStoragePath"
    dst: "str | ObjectStoragePath"
    source_conn_id: "str | None"
    dest_conn_id: "str | None"
    overwrite: "bool"
