# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class GoogleDriveToLocalOperator(BaseOperator):
    output_file: "str"
    file_name: "str"
    folder_id: "str"
    drive_id: "str | None"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
