# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.operators.base_aws import (
    AwsBaseOperator,
)


class EventBridgePutEventsOperator(AwsBaseOperator):
    entries: "list[dict]"
    endpoint_id: "str | None"


class EventBridgePutRuleOperator(AwsBaseOperator):
    name: "str"
    description: "str | None"
    event_bus_name: "str | None"
    event_pattern: "str | None"
    role_arn: "str | None"
    schedule_expression: "str | None"
    state: "str | None"
    tags: "list | None"


class EventBridgeEnableRuleOperator(AwsBaseOperator):
    name: "str"
    event_bus_name: "str | None"


class EventBridgeDisableRuleOperator(AwsBaseOperator):
    name: "str"
    event_bus_name: "str | None"
