# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.cncf.kubernetes.operators.pod import (
    KubernetesPodOperator,
)


class SparkKubernetesOperator(KubernetesPodOperator):
    image: "str | None"
    code_path: "str | None"
    namespace: "str"
    name: "str"
    application_file: "str | None"
    template_spec: "_empty"
    get_logs: "bool"
    do_xcom_push: "bool"
    success_run_history_limit: "int"
    startup_timeout_seconds: "_empty"
    log_events_on_failure: "bool"
    reattach_on_restart: "bool"
    delete_on_termination: "bool"
    kubernetes_conn_id: "str"
