# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class CloudVisionCreateProductSetOperator(GoogleCloudBaseOperator):
    product_set: "dict | ProductSet"
    location: "str"
    project_id: "str"
    product_set_id: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudVisionGetProductSetOperator(GoogleCloudBaseOperator):
    location: "str"
    product_set_id: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudVisionUpdateProductSetOperator(GoogleCloudBaseOperator):
    product_set: "dict | ProductSet"
    location: "str | None"
    product_set_id: "str | None"
    project_id: "str"
    update_mask: "dict | FieldMask | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudVisionDeleteProductSetOperator(GoogleCloudBaseOperator):
    location: "str"
    product_set_id: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudVisionCreateProductOperator(GoogleCloudBaseOperator):
    location: "str"
    product: "str"
    project_id: "str"
    product_id: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudVisionGetProductOperator(GoogleCloudBaseOperator):
    location: "str"
    product_id: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudVisionUpdateProductOperator(GoogleCloudBaseOperator):
    product: "dict | Product"
    location: "str | None"
    product_id: "str | None"
    project_id: "str"
    update_mask: "dict | FieldMask | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudVisionDeleteProductOperator(GoogleCloudBaseOperator):
    location: "str"
    product_id: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudVisionImageAnnotateOperator(GoogleCloudBaseOperator):
    request: "dict | AnnotateImageRequest"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudVisionCreateReferenceImageOperator(GoogleCloudBaseOperator):
    location: "str"
    reference_image: "dict | ReferenceImage"
    product_id: "str"
    reference_image_id: "str | None"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudVisionDeleteReferenceImageOperator(GoogleCloudBaseOperator):
    location: "str"
    product_id: "str"
    reference_image_id: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudVisionAddProductToProductSetOperator(GoogleCloudBaseOperator):
    product_set_id: "str"
    product_id: "str"
    location: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudVisionRemoveProductFromProductSetOperator(GoogleCloudBaseOperator):
    product_set_id: "str"
    product_id: "str"
    location: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudVisionDetectTextOperator(GoogleCloudBaseOperator):
    image: "dict | Image"
    max_results: "int | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    language_hints: "str | list[str] | None"
    web_detection_params: "dict | None"
    additional_properties: "dict | None"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudVisionTextDetectOperator(GoogleCloudBaseOperator):
    image: "dict | Image"
    max_results: "int | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    language_hints: "str | list[str] | None"
    web_detection_params: "dict | None"
    additional_properties: "dict | None"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudVisionDetectImageLabelsOperator(GoogleCloudBaseOperator):
    image: "dict | Image"
    max_results: "int | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    additional_properties: "dict | None"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudVisionDetectImageSafeSearchOperator(GoogleCloudBaseOperator):
    image: "dict | Image"
    max_results: "int | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    additional_properties: "dict | None"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
