# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class S3ToRedshiftOperator(BaseOperator):
    schema: "str"
    table: "str"
    s3_bucket: "str"
    s3_key: "str"
    redshift_conn_id: "str"
    aws_conn_id: "str | None"
    verify: "bool | str | None"
    column_list: "list[str] | None"
    copy_options: "list | None"
    autocommit: "bool"
    method: "str"
    upsert_keys: "list[str] | None"
    redshift_data_api_kwargs: "dict | None"
