# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class GoogleSheetsToGCSOperator(BaseOperator):
    spreadsheet_id: "str"
    destination_bucket: "str"
    sheet_filter: "list[str] | None"
    destination_path: "str | None"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
