# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.http.operators.http import HttpOperator


class DiscordWebhookOperator(HttpOperator):
    http_conn_id: "str | None"
    webhook_endpoint: "str | None"
    message: "str"
    username: "str | None"
    avatar_url: "str | None"
    tts: "bool"
    proxy: "str | None"
