# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class DatadogSensor(BaseSensorOperator):
    datadog_conn_id: "str"
    from_seconds_ago: "int"
    up_to_seconds_from_now: "int"
    priority: "str | None"
    sources: "str | None"
    tags: "list[str] | None"
    response_check: "Callable[[dict[str, Any]], bool] | None"
