# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class CohereEmbeddingOperator(BaseOperator):
    input_text: "list[str] | str"
    conn_id: "str"
    timeout: "int | None"
    max_retries: "int | None"
