# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class GenericTransfer(BaseOperator):
    sql: "str"
    destination_table: "str"
    source_conn_id: "str"
    destination_conn_id: "str"
    preoperator: "str | list[str] | None"
    insert_args: "dict | None"
