# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class S3ToDynamoDBOperator(BaseOperator):
    s3_bucket: "str"
    s3_key: "str"
    dynamodb_table_name: "str"
    dynamodb_key_schema: "list[KeySchema]"
    dynamodb_attributes: "list[AttributeDefinition] | None"
    dynamodb_tmp_table_prefix: "str"
    delete_on_error: "bool"
    use_existing_table: "bool"
    input_format: "Literal['CSV', 'DYNAMODB_JSON', 'ION']"
    billing_mode: "Literal['PROVISIONED', 'PAY_PER_REQUEST']"
    import_table_kwargs: "dict[str, Any] | None"
    import_table_creation_kwargs: "dict[str, Any] | None"
    wait_for_completion: "bool"
    check_interval: "int"
    max_attempts: "int"
    aws_conn_id: "str | None"
