# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class KylinCubeOperator(BaseOperator):
    kylin_conn_id: "str"
    project: "str | None"
    cube: "str | None"
    dsn: "str | None"
    command: "str | None"
    start_time: "str | None"
    end_time: "str | None"
    offset_start: "str | None"
    offset_end: "str | None"
    segment_name: "str | None"
    is_track_job: "bool"
    interval: "int"
    timeout: "int"
    eager_error_status: "_empty"
