# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class AddOneOperator(BaseOperator):
    value: "_empty"


class SumItOperator(BaseOperator):
    values: "_empty"
