# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class CloudDLPCancelDLPJobOperator(GoogleCloudBaseOperator):
    dlp_job_id: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPCreateDeidentifyTemplateOperator(GoogleCloudBaseOperator):
    organization_id: "str | None"
    project_id: "str"
    deidentify_template: "dict | DeidentifyTemplate | None"
    template_id: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPCreateDLPJobOperator(GoogleCloudBaseOperator):
    project_id: "str"
    inspect_job: "dict | InspectJobConfig | None"
    risk_job: "dict | RiskAnalysisJobConfig | None"
    job_id: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    wait_until_finished: "bool"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPCreateInspectTemplateOperator(GoogleCloudBaseOperator):
    organization_id: "str | None"
    project_id: "str"
    inspect_template: "InspectTemplate | None"
    template_id: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPCreateJobTriggerOperator(GoogleCloudBaseOperator):
    project_id: "str"
    job_trigger: "dict | JobTrigger | None"
    trigger_id: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPCreateStoredInfoTypeOperator(GoogleCloudBaseOperator):
    organization_id: "str | None"
    project_id: "str"
    config: "StoredInfoTypeConfig | None"
    stored_info_type_id: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPDeidentifyContentOperator(GoogleCloudBaseOperator):
    project_id: "str"
    deidentify_config: "dict | DeidentifyConfig | None"
    inspect_config: "dict | InspectConfig | None"
    item: "dict | ContentItem | None"
    inspect_template_name: "str | None"
    deidentify_template_name: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPDeleteDeidentifyTemplateOperator(GoogleCloudBaseOperator):
    template_id: "str"
    organization_id: "str | None"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPDeleteDLPJobOperator(GoogleCloudBaseOperator):
    dlp_job_id: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPDeleteInspectTemplateOperator(GoogleCloudBaseOperator):
    template_id: "str"
    organization_id: "str | None"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPDeleteJobTriggerOperator(GoogleCloudBaseOperator):
    job_trigger_id: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPDeleteStoredInfoTypeOperator(GoogleCloudBaseOperator):
    stored_info_type_id: "str"
    organization_id: "str | None"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPGetDeidentifyTemplateOperator(GoogleCloudBaseOperator):
    template_id: "str"
    organization_id: "str | None"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPGetDLPJobOperator(GoogleCloudBaseOperator):
    dlp_job_id: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPGetInspectTemplateOperator(GoogleCloudBaseOperator):
    template_id: "str"
    organization_id: "str | None"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPGetDLPJobTriggerOperator(GoogleCloudBaseOperator):
    job_trigger_id: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPGetStoredInfoTypeOperator(GoogleCloudBaseOperator):
    stored_info_type_id: "str"
    organization_id: "str | None"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPInspectContentOperator(GoogleCloudBaseOperator):
    project_id: "str"
    inspect_config: "dict | InspectConfig | None"
    item: "dict | ContentItem | None"
    inspect_template_name: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPListDeidentifyTemplatesOperator(GoogleCloudBaseOperator):
    organization_id: "str | None"
    project_id: "str"
    page_size: "int | None"
    order_by: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPListDLPJobsOperator(GoogleCloudBaseOperator):
    project_id: "str"
    results_filter: "str | None"
    page_size: "int | None"
    job_type: "str | None"
    order_by: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPListInfoTypesOperator(GoogleCloudBaseOperator):
    project_id: "str"
    language_code: "str | None"
    results_filter: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPListInspectTemplatesOperator(GoogleCloudBaseOperator):
    organization_id: "str | None"
    project_id: "str"
    page_size: "int | None"
    order_by: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPListJobTriggersOperator(GoogleCloudBaseOperator):
    project_id: "str"
    page_size: "int | None"
    order_by: "str | None"
    results_filter: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPListStoredInfoTypesOperator(GoogleCloudBaseOperator):
    organization_id: "str | None"
    project_id: "str"
    page_size: "int | None"
    order_by: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPRedactImageOperator(GoogleCloudBaseOperator):
    project_id: "str"
    inspect_config: "dict | InspectConfig | None"
    image_redaction_configs: (
        "None | (list[dict] | list[RedactImageRequest.ImageRedactionConfig])"
    )
    include_findings: "bool | None"
    byte_item: "dict | ByteContentItem | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPReidentifyContentOperator(GoogleCloudBaseOperator):
    project_id: "str"
    reidentify_config: "dict | DeidentifyConfig | None"
    inspect_config: "dict | InspectConfig | None"
    item: "dict | ContentItem | None"
    inspect_template_name: "str | None"
    reidentify_template_name: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPUpdateDeidentifyTemplateOperator(GoogleCloudBaseOperator):
    template_id: "str"
    organization_id: "str | None"
    project_id: "str"
    deidentify_template: "dict | DeidentifyTemplate | None"
    update_mask: "dict | FieldMask | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPUpdateInspectTemplateOperator(GoogleCloudBaseOperator):
    template_id: "str"
    organization_id: "str | None"
    project_id: "str"
    inspect_template: "dict | InspectTemplate | None"
    update_mask: "dict | FieldMask | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPUpdateJobTriggerOperator(GoogleCloudBaseOperator):
    job_trigger_id: "_empty"
    project_id: "str"
    job_trigger: "dict | JobTrigger | None"
    update_mask: "dict | FieldMask | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPUpdateStoredInfoTypeOperator(GoogleCloudBaseOperator):
    stored_info_type_id: "_empty"
    organization_id: "str | None"
    project_id: "str"
    config: "dict | StoredInfoTypeConfig | None"
    update_mask: "dict | FieldMask | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
