# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class SFTPOperator(BaseOperator):
    ssh_hook: "SSHHook | None"
    sftp_hook: "SFTPHook | None"
    ssh_conn_id: "str | None"
    remote_host: "str | None"
    local_filepath: "str | list[str]"
    remote_filepath: "str | list[str]"
    operation: "str"
    confirm: "bool"
    create_intermediate_dirs: "bool"
