# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class CloudDatastoreExportEntitiesOperator(GoogleCloudBaseOperator):
    bucket: "str"
    namespace: "str | None"
    datastore_conn_id: "str"
    cloud_storage_conn_id: "str"
    entity_filter: "dict | None"
    labels: "dict | None"
    polling_interval_in_seconds: "int"
    overwrite_existing: "bool"
    project_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDatastoreImportEntitiesOperator(GoogleCloudBaseOperator):
    bucket: "str"
    file: "str"
    namespace: "str | None"
    entity_filter: "dict | None"
    labels: "dict | None"
    datastore_conn_id: "str"
    polling_interval_in_seconds: "float"
    project_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDatastoreAllocateIdsOperator(GoogleCloudBaseOperator):
    partial_keys: "list"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDatastoreBeginTransactionOperator(GoogleCloudBaseOperator):
    transaction_options: "dict[str, Any]"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDatastoreCommitOperator(GoogleCloudBaseOperator):
    body: "dict[str, Any]"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDatastoreRollbackOperator(GoogleCloudBaseOperator):
    transaction: "str"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDatastoreRunQueryOperator(GoogleCloudBaseOperator):
    body: "dict[str, Any]"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDatastoreGetOperationOperator(GoogleCloudBaseOperator):
    name: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDatastoreDeleteOperationOperator(GoogleCloudBaseOperator):
    name: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
