# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.sensors.base_aws import AwsBaseSensor


class OpenSearchServerlessCollectionActiveSensor(AwsBaseSensor):
    collection_id: "str | None"
    collection_name: "str | None"
    poke_interval: "int"
    max_retries: "int"
    deferrable: "bool"
