# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class S3ToMySqlOperator(BaseOperator):
    s3_source_key: "str"
    mysql_table: "str"
    mysql_duplicate_key_handling: "str"
    mysql_extra_options: "str | None"
    aws_conn_id: "str | None"
    mysql_conn_id: "str"
    mysql_local_infile: "bool"
