# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class TimeDeltaSensor(BaseSensorOperator):
    delta: "_empty"


class TimeDeltaSensorAsync(TimeDeltaSensor):
    end_from_trigger: "bool"
    delta: "_empty"
