# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class CloudBuildCancelBuildOperator(GoogleCloudBaseOperator):
    id_: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    location: "str"


class CloudBuildCreateBuildOperator(GoogleCloudBaseOperator):
    build: "dict | Build"
    project_id: "str"
    wait: "bool"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    poll_interval: "float"
    deferrable: "bool"
    location: "str"


class CloudBuildCreateBuildTriggerOperator(GoogleCloudBaseOperator):
    trigger: "dict | BuildTrigger"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    location: "str"


class CloudBuildDeleteBuildTriggerOperator(GoogleCloudBaseOperator):
    trigger_id: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    location: "str"


class CloudBuildGetBuildOperator(GoogleCloudBaseOperator):
    id_: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    location: "str"


class CloudBuildGetBuildTriggerOperator(GoogleCloudBaseOperator):
    trigger_id: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    location: "str"


class CloudBuildListBuildTriggersOperator(GoogleCloudBaseOperator):
    location: "str"
    project_id: "str"
    page_size: "int | None"
    page_token: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudBuildListBuildsOperator(GoogleCloudBaseOperator):
    location: "str"
    project_id: "str"
    page_size: "int | None"
    filter_: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudBuildRetryBuildOperator(GoogleCloudBaseOperator):
    id_: "str"
    project_id: "str"
    wait: "bool"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    location: "str"


class CloudBuildRunBuildTriggerOperator(GoogleCloudBaseOperator):
    trigger_id: "str"
    source: "dict | RepoSource"
    project_id: "str"
    wait: "bool"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    location: "str"


class CloudBuildUpdateBuildTriggerOperator(GoogleCloudBaseOperator):
    trigger_id: "str"
    trigger: "dict | BuildTrigger"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    location: "str"
