# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.sensors.base_aws import AwsBaseSensor


class DmsTaskBaseSensor(AwsBaseSensor):
    replication_task_arn: "str"
    target_statuses: "Iterable[str] | None"
    termination_statuses: "Iterable[str] | None"


class DmsTaskCompletedSensor(DmsTaskBaseSensor):
    pass
