# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class AirbyteTriggerSyncOperator(BaseOperator):
    connection_id: "str"
    airbyte_conn_id: "str"
    asynchronous: "bool"
    deferrable: "bool"
    api_version: "str"
    api_type: "Literal['config', 'cloud']"
    wait_seconds: "float"
    timeout: "float"
